@@ -24,7 +24,12 @@ static test_case_result_t relationship_CRURDR( test_fixture_t *fix );
 test_suite_t ctrl_classifier_controller_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "ctrl_classifier_controller_test", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "ctrl_classifier_controller_test",
+                     TEST_CATEGORY_INTEGRATION | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "classifier_create_read_modify_read", &classifier_create_read_modify_read );
     test_suite_add_test_case( &result, "features_CRURDR", &features_CRURDR );
     test_suite_add_test_case( &result, "relationship_CRURDR", &relationship_CRURDR );
