@@ -30,7 +30,12 @@ static test_case_result_t repair_ill_feature_relationship( test_fixture_t *fix )
 test_suite_t ctrl_consistency_checker_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "ctrl_classifier_consistency_checker_test", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "ctrl_classifier_consistency_checker_test",
+                     TEST_CATEGORY_INTEGRATION | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "diagram_two_roots_consistency", &diagram_two_roots_consistency );
     test_suite_add_test_case( &result, "diagram_missing_parent_consistency", &diagram_missing_parent_consistency );
     test_suite_add_test_case( &result, "diagram_circular_referenced_diagrams_consistency", &diagram_circular_referenced_diagrams_consistency );
