@@ -24,7 +24,12 @@ static test_case_result_t delete_set_not_possible( test_fixture_t *fix );
 test_suite_t ctrl_multi_step_changer_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "ctrl_multi_step_changer_test", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "ctrl_multi_step_changer_test",
+                     TEST_CATEGORY_INTEGRATION | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "delete_set_successfully", &delete_set_successfully );
     test_suite_add_test_case( &result, "delete_set_not_possible", &delete_set_not_possible );
     return result;
