@@ -255,32 +255,6 @@ u8_error_t data_database_diagram_reader_private_open ( data_database_diagram_rea
  */
 u8_error_t data_database_diagram_reader_private_close ( data_database_diagram_reader_t *this_ );
 
-/*!
- *  \brief creates a prepared statement.
- *
- *  \param this_ pointer to own object attributes
- *  \param string_statement statement as string to be prepared
- *  \param string_size size of string_statement in bytes, including the terminating zero
- *  \param[out] out_statement_ptr address of a pointer. The pointer is modifies as to point to a statement object.
- *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- */
-static inline u8_error_t data_database_diagram_reader_private_prepare_statement ( data_database_diagram_reader_t *this_,
-                                                                                  const char *string_statement,
-                                                                                  int string_size,
-                                                                                  sqlite3_stmt **out_statement_ptr
-                                                                                );
-
-/*!
- *  \brief finalizes a prepared statement.
- *
- *  \param this_ pointer to own object attributes
- *  \param statement_ptr pointer to a statement object
- *  \return U8_ERROR_NONE in case of success, an error code in case of error.
- */
-static inline u8_error_t data_database_diagram_reader_private_finalize_statement ( data_database_diagram_reader_t *this_,
-                                                                                   sqlite3_stmt *statement_ptr
-                                                                                 );
-
 /*!
  *  \brief resets a statement only, without binding.
  *
@@ -328,7 +302,7 @@ static inline u8_error_t data_database_diagram_reader_private_bind_text_to_state
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
