@@ -74,7 +74,7 @@ void data_database_writer_db_change_callback ( data_database_writer_t *this_, da
  *
  *  \param this_ pointer to own object attributes
  *  \param diagram data of the new diagram record to be created. The id should be DATA_ROW_ID_VOID unless a diagram with known, unique id shall be created.
- *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
+ *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if the id shall not be returned.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t data_database_writer_create_diagram ( data_database_writer_t *this_, const data_diagram_t *diagram, data_row_id_t* out_new_id );
@@ -166,7 +166,7 @@ u8_error_t data_database_writer_update_diagram_parent_id ( data_database_writer_
  *  \param this_ pointer to own object attributes
  *  \param classifier data of the new classifier record to be created.
  *                    The id should be DATA_ROW_ID_VOID unless a classifier with known, unique id shall be created.
- *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
+ *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if the id shall not be returned.
  *  \return U8_ERROR_NONE in case of success, U8_ERROR_DUPLICATE if duplicate id or duplicate name, otherwise an other error code.
  */
 u8_error_t data_database_writer_create_classifier( data_database_writer_t *this_, const data_classifier_t *classifier, data_row_id_t* out_new_id );
@@ -269,7 +269,7 @@ u8_error_t data_database_writer_update_classifier_list_order ( data_database_wri
  *
  *  \param this_ pointer to own object attributes
  *  \param diagramelement data of the new diagramelement record to be created. The id should be DATA_ROW_ID_VOID unless a diagramelement with known, unique id shall be created.
- *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
+ *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if the id shall not be returned.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t data_database_writer_create_diagramelement( data_database_writer_t *this_, const data_diagramelement_t *diagramelement, data_row_id_t* out_new_id );
@@ -313,7 +313,7 @@ u8_error_t data_database_writer_update_diagramelement_focused_feature_id ( data_
  *
  *  \param this_ pointer to own object attributes
  *  \param feature data of the new feature record to be created. The id should be DATA_ROW_ID_VOID unless a feature with known, unique id shall be created.
- *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
+ *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if the id shall not be returned.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t data_database_writer_create_feature ( data_database_writer_t *this_, const data_feature_t *feature, data_row_id_t* out_new_id );
@@ -390,7 +390,7 @@ u8_error_t data_database_writer_update_feature_list_order ( data_database_writer
  *
  *  \param this_ pointer to own object attributes
  *  \param relationship data of the new relationship record to be created. The id should be DATA_ROW_ID_VOID unless a relationship with known, unique id shall be created.
- *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if old data shall not be returned.
+ *  \param[out] out_new_id storage, where the id of the newly created record is stored. NULL if the id shall not be returned.
  *  \return U8_ERROR_NONE in case of success, an error code in case of error.
  */
 u8_error_t data_database_writer_create_relationship ( data_database_writer_t *this_, const data_relationship_t *relationship, data_row_id_t* out_new_id );
@@ -460,36 +460,11 @@ u8_error_t data_database_writer_update_relationship_description ( data_database_
  */
 u8_error_t data_database_writer_update_relationship_list_order ( data_database_writer_t *this_, data_row_id_t relationship_id, int32_t new_relationship_list_order, data_relationship_t *out_old_relationship );
 
-/* ================================ private ================================ */
-
-/*!
- *  \brief executes a single SQL command
- *
- *  This function does not care about locks. It does not sent notifications.
- *
- *  \param this_ pointer to own object attributes
- *  \param sql_statement statement to be executed.
- *  \param[out] out_new_id if fetch_new_id, the id of the newly created row is returned
- *  \return U8_ERROR_NONE in case of success, U8_ERROR_DUPLICATE if a key is not unique; U8_ERROR_READ_ONLY_DB if read only
- */
-u8_error_t data_database_writer_private_execute_create_command ( data_database_writer_t *this_, const char* sql_statement, data_row_id_t* out_new_id );
-
-/*!
- *  \brief sends one SQL command to the database within a transaction
- *
- *  This function does not care about locks. It does not sent notifications.
- *
- *  \param this_ pointer to own object attributes
- *  \param sql_statement statement to be executed.
- *  \return U8_ERROR_NONE in case of success, an error id otherwise; U8_ERROR_READ_ONLY_DB if read only
- */
-u8_error_t data_database_writer_private_transaction_issue_command ( data_database_writer_t *this_, const char* sql_statement );
-
 #endif  /* DATA_DATABASE_WRITER_H */
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
