@@ -288,14 +288,16 @@ static const char *DATA_DATABASE_COMMIT_TRANSACTION =
 void data_database_init ( data_database_t *this_ )
 {
     U8_TRACE_BEGIN();
-
-    U8_LOG_EVENT_STR( "sqlite3_libversion:", sqlite3_libversion() );
+    U8_LOG_EVENT_INT( "compiled against sqlite3:    ", SQLITE_VERSION_NUMBER );
+    U8_LOG_EVENT_STR( "linked to sqlite3_libversion:", sqlite3_libversion() );
 
     (*this_).db_file_name = utf8stringbuf_init( sizeof((*this_).private_db_file_name_buffer), (*this_).private_db_file_name_buffer );
     utf8stringbuf_clear( (*this_).db_file_name );
 
     g_mutex_init ( &((*this_).lock_on_write) );
+    g_mutex_lock ( &((*this_).lock_on_write) );  /* (*this_).locked_on_write may only be changed when having the lock */
     (*this_).locked_on_write = false;
+    g_mutex_unlock ( &((*this_).lock_on_write) );  /* this call manages a memory barrier that allows for cache coherence */
 
     u8_error_t result = data_database_lock_on_write( this_ );
     {
@@ -592,6 +594,10 @@ u8_error_t data_database_flush_caches ( data_database_t *this_ )
                               );
         }
     }
+    else
+    {
+        result = U8_ERROR_NO_DB;
+    }
 
     U8_TRACE_END_ERR( result );
     return result;
