@@ -15,12 +15,7 @@
 #include "ctrl_controller.h"
 #include "data_rules.h"
 #include "utf8stringbuf/utf8stringbuf.h"
-#if ( GTK_MAJOR_VERSION >= 4 )
 #include <gdk/gdkclipboard.h>
-#else
-#include <gtk/gtk.h>
-typedef GtkClipboard GdkClipboard;
-#endif
 
 /*!
  *  \brief attributes of the serdes object
@@ -73,7 +68,6 @@ void gui_clipboard_destroy ( gui_clipboard_t *this_ );
  */
 void gui_clipboard_request_clipboard_text( gui_clipboard_t *this_, data_row_id_t destination_diagram_id );
 
-#if ( GTK_MAJOR_VERSION >= 4 )
 /*!
  *  \brief callback that informs that the text from the clipboard is now available.
  *
@@ -88,22 +82,6 @@ void gui_clipboard_clipboard_text_received_callback( GObject *source_object,
                                                      GAsyncResult* res,
                                                      gpointer user_data
                                                    );
-#else
-/*!
- *  \brief callback that informs that the text from the clipboard is now available.
- *
- *  Thi function implicitly assumes that the clipboard text shall be imported and calls
- *  gui_clipboard_private_copy_clipboard_to_db.
- *
- *  \param clipboard pointer to GtkClipboard
- *  \param text pointer to the clipboard text or NULL if there is no text
- *  \param data this_ pointer to own object attributes
- */
-void gui_clipboard_clipboard_text_received_callback( GdkClipboard *clipboard,
-                                                     const gchar *text,
-                                                     gpointer data
-                                                   );
-#endif
 
 /*!
  *  \brief copies a set of objects to the clipboard
