@@ -9,6 +9,8 @@
  */
 
 #include "sketch/gui_sketch_action.h"
+#include "layout/layout_subelement_id.h"
+#include "layout/layout_subelement_kind.h"
 #include "set/data_small_set.h"
 #include "set/data_full_id.h"
 #include <glib-object.h>
@@ -16,9 +18,9 @@
 #include <stdint.h>
 
 /*!
- *  \brief attributes of the sketch marker
+ *  \brief attributes of the marked set
  *
- *  A sketch marker keeps track of the currently focused and selected elements
+ *  A marked set keeps track of the currently focused and selected elements
  *  and knows the currently highlighted elements.
  *
  *  Even buttons (active icons) are represented to fit into the current redrawing concept.
@@ -32,6 +34,7 @@ struct gui_marked_set_struct {
     data_id_t focused_diagram;  /*!< the focused diagram is the place where to e.g. insert pasted objects. */
                                 /*!< Even if the focused object is VOID, the focused_diagram should be set */
     data_id_t highlighted;  /*!<  references the one highlighted/mouse over object */
+    layout_subelement_kind_t highlighted_kind;  /*!< specifies which part of the element is highlighted */
     data_id_t highlighted_diagram;  /*!< the highlighted diagram, the diagram to zoom in when clicking on the highlighted id */
     gui_sketch_action_t highlighted_button;  /*!<  the buttons action-id if the highlighted/mouse over object is a button */
     data_small_set_t selected_set;  /*!<  references all selected objects (pink corners) */
@@ -108,6 +111,14 @@ static inline bool gui_marked_set_has_focus ( const gui_marked_set_t *this_ );
  */
 static inline data_id_t gui_marked_set_get_highlighted ( const gui_marked_set_t *this_ );
 
+/*!
+ *  \brief gets the highlighted_kind of the highlighted subelement
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return kind of the highlighted subelement, LAYOUT_SUBELEMENT_KIND_VOID if no element was set.
+ */
+static inline layout_subelement_kind_t gui_marked_set_get_highlighted_kind ( const gui_marked_set_t *this_ );
+
 /*!
  *  \brief gets the highlighted_diagram id
  *
@@ -171,8 +182,9 @@ static inline void gui_marked_set_clear_selected_set ( gui_marked_set_t *this_ )
 static inline void gui_marked_set_set_focused ( gui_marked_set_t *this_, data_full_id_t obj_id, data_id_t diagram_id );
 
 /*!
- *  \brief sets the highlighted object id and the highlighted_diagram id
+ *  \brief sets the highlighted id and the highlighted_diagram id
  *
+ *  The highlighted subelement kind is set to LAYOUT_SUBELEMENT_KIND_VOID.
  *  Unsets the highlighted button.
  *
  *  \param this_ pointer to own object attributes
@@ -181,10 +193,24 @@ static inline void gui_marked_set_set_focused ( gui_marked_set_t *this_, data_fu
  */
 static inline void gui_marked_set_set_highlighted ( gui_marked_set_t *this_, data_id_t obj_id, data_id_t diagram_id );
 
+/*!
+ *  \brief sets the highlighted id, highlighted_kind and the highlighted_diagram id
+ *
+ *  Unsets the highlighted button.
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param subelement_id the id and kind to set as highlighted, can be identical to diagram_id
+ *  \param diagram_id the id of the highlighted diagram; identical or parent to obj_id
+ */
+static inline void gui_marked_set_set_highlighted_subelement ( gui_marked_set_t *this_,
+                                                               const layout_subelement_id_t *subelement_id,
+                                                               data_id_t diagram_id
+                                                             );
+
 /*!
  *  \brief sets the highlighted button id
  *
- *  Unsets the highlighted object and highlighted_diagram id.
+ *  Unsets the highlighted object, highlighted_kind and highlighted_diagram id.
  *
  *  \param this_ pointer to own object attributes
  *  \param button_id the action-id of the button to set as highlighted, may be context specific
