@@ -33,10 +33,10 @@ typedef enum pos_nav_tree_node_type_enum pos_nav_tree_node_type_t;
  *  \return icon representing the pos_nav_tree_node_type_t,
  *          gui_resources_get_type_undef in case of POS_NAV_TREE_NODE_TYPE_VOID
  */
-static inline const GdkPixbuf * pos_nav_tree_node_type_get_icon ( pos_nav_tree_node_type_t this_,
-                                                                  bool highlight,
-                                                                  gui_resources_t *resources
-                                                                );
+static inline GdkTexture * pos_nav_tree_node_type_get_icon ( pos_nav_tree_node_type_t this_,
+                                                             bool highlight,
+                                                             gui_resources_t *resources
+                                                           );
 
 #include "pos_nav_tree_node_type.inl"
 
@@ -44,7 +44,7 @@ static inline const GdkPixbuf * pos_nav_tree_node_type_get_icon ( pos_nav_tree_n
 
 
 /*
-Copyright 2021-2023 Andreas Warnke
+Copyright 2021-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
