@@ -9,14 +9,15 @@
  */
 
 #include "sketch/gui_sketch_card.h"
+#include "sketch/gui_sketch_card_painter.h"
 #include "sketch/gui_sketch_nav_tree.h"
 #include "sketch/gui_sketch_result_list.h"
 #include "sketch/gui_sketch_drag_state.h"
 #include "sketch/gui_sketch_object_creator.h"
-#include "sketch/gui_sketch_overlay.h"
 #include "sketch/gui_sketch_background.h"
 #include "sketch/gui_sketch_request.h"
 #include "sketch/gui_sketch_texture.h"
+#include "layout/layout_subelement_id.h"
 #include "gui_toolbox.h"
 #include "gui_marked_set.h"
 #include "gui_resources.h"
@@ -69,7 +70,7 @@ struct gui_sketch_area_struct {
     gui_sketch_texture_t texture_downloader;  /*!< own instance of an gui_sketch_texture_t */
 
     /* sub widgets, things that can draw provided input-data */
-    gui_sketch_overlay_t overlay;  /*!< own instance of sketch overlay */
+    gui_sketch_card_painter_t card_overlay;  /*!< own instance of sketch card overlay */
     gui_sketch_background_t background;  /*!< own instance of sketch background */
     gui_sketch_card_t cards[GUI_SKETCH_AREA_CONST_MAX_CARDS];  /*!< own instance of card objects that draw diagrams */
     uint32_t card_num;
@@ -289,6 +290,8 @@ void gui_sketch_area_tool_changed_callback( GtkWidget *widget, gui_tool_t tool,
 /*!
  *  \brief gets the diagram-id of the diagram and the object-id of the object at a given position
  *
+ *  This function is intended for use in SEARCH and NAVIGATE modes only.
+ *
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
@@ -313,44 +316,23 @@ static inline void gui_sketch_area_private_get_diagram_and_object_id_at_pos ( gu
 static inline gui_sketch_card_t *gui_sketch_area_private_get_card_at_pos ( gui_sketch_area_t *this_, int32_t x, int32_t y );
 
 /*!
- *  \brief gets the object-id of the object at a given position
+ *  \brief gets the out_element_id of the out_element at a given position
  *
  *  Nav-Tree and Result-List objects are ignored; this function is intended for use in EDIT and CREATE modes.
+ *  In case the position is a space, VOID is returned as out_element_id.
  *
  *  \param this_ pointer to own object attributes
  *  \param x x-position
  *  \param y y-position
- *  \param filter a filter for object types. E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param[out] out_object_id the object id at the given location. The id is invalid if there is no object at the given location.
- *  \param[out] out_diagram_id the diagram id at given location. The id is invalid if there is no diagram.
+ *  \param filter_lifelines a filter for object types. true will return the classifier instead of the lifeline-feature.
+ *  \param[out] out_element_id the element id at the given location. The id is invalid if there is no element.
+ *  \param[out] out_diagram_id the diagram id at the given location. The id is invalid if there is no diagram.
  */
-static inline void gui_sketch_area_private_get_object_id_at_pos ( gui_sketch_area_t *this_,
-                                                                  int32_t x,
-                                                                  int32_t y,
-                                                                  pencil_type_filter_t filter,
-                                                                  data_full_id_t* out_object_id,
-                                                                  data_id_t* out_diagram_id
-                                                                );
-
-/*!
- *  \brief gets the object-id of the surrounding object and a selected-part-info at a given position
- *
- *  Nav-Tree and Result-List objects are ignored; this function is intended for use in EDIT and CREATE modes.
- *
- *  \param this_ pointer to own object attributes
- *  \param x x-position
- *  \param y y-position
- *  \param filter a filter for object types. E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param[out] out_object_id the object id at the given location. The id is invalid if there is no object at the given location.
- *  \param[out] out_surrounding_id the id of the embracing object at the given location. The id is invalid if there is no object embracing the given location.
- *  \param[out] out_diagram_id the diagram id at given location. The id is invalid if there is no diagram.
- */
-static inline void gui_sketch_area_private_get_object_ids_at_pos ( gui_sketch_area_t *this_,
+static inline void gui_sketch_area_private_get_element_id_at_pos ( gui_sketch_area_t *this_,
                                                                    int32_t x,
                                                                    int32_t y,
-                                                                   pencil_type_filter_t filter,
-                                                                   data_full_id_t* out_object_id,
-                                                                   data_full_id_t* out_surrounding_id,
+                                                                   bool filter_lifelines,
+                                                                   data_full_id_t* out_element_id,
                                                                    data_id_t* out_diagram_id
                                                                  );
 
