@@ -10,7 +10,10 @@
 
 #include "sketch/gui_sketch_marker.h"
 #include "sketch/gui_sketch_snap_state.h"
+#include "sketch/gui_sketch_drag_state.h"
+#include "layout/layout_subelement_id.h"
 #include "gui_marked_set.h"
+#include "gui_tool.h"
 #include "shape/shape_int_rectangle.h"
 #include "storage/data_database.h"
 #include "ctrl_controller.h"
@@ -18,7 +21,6 @@
 #include "set/data_visible_set.h"
 #include "set/data_full_id.h"
 #include "set/data_profile_part.h"
-#include "filter/pencil_type_filter.h"
 #include "layout/layout_order.h"
 #include <gtk/gtk.h>
 #include <stdbool.h>
@@ -112,6 +114,64 @@ static inline bool gui_sketch_card_is_visible( const gui_sketch_card_t *this_ );
  */
 static inline void gui_sketch_card_set_visible( gui_sketch_card_t *this_, bool visible );
 
+/*!
+ *  \brief gets the id and kind of the element-part at a given position
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param x x-position
+ *  \param y y-position
+ *  \param filter_lifelines a filter for object types. true will return the classifier instead of the lifeline-feature.
+ *  \return id and kind of element-part at the given position. The id is invalid if there is no element at the given position.
+ */
+layout_subelement_id_t gui_sketch_card_get_element_at_pos ( const gui_sketch_card_t *this_,
+                                                            int32_t x,
+                                                            int32_t y,
+                                                            bool filter_lifelines
+                                                          );
+
+/*!
+ *  \brief gets the id and kind of the classifier-part at a given position
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param x x-position
+ *  \param y y-position
+ *  \return id and kind of element-part at the given position. The id is invalid if there is no element at the given position.
+ */
+layout_subelement_id_t gui_sketch_card_private_get_classifier_at_pos ( const gui_sketch_card_t *this_,
+                                                                       int32_t x,
+                                                                       int32_t y
+                                                                     );
+
+/*!
+ *  \brief gets the id and kind of the feature-part at a given position
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param x x-position
+ *  \param y y-position
+ *  \param filter_lifelines a filter for object types. true will return the classifier instead of the lifeline-feature.
+ *  \return id and kind of element-part at the given position. The id is invalid if there is no element at the given position.
+ */
+layout_subelement_id_t gui_sketch_card_private_get_feature_at_pos ( const gui_sketch_card_t *this_,
+                                                                    int32_t x,
+                                                                    int32_t y,
+                                                                    bool filter_lifelines
+                                                                  );
+
+/*!
+ *  \brief gets the id and kind of the relationship-part at a given position
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param x x-position
+ *  \param y y-position
+ *  \param snap_distance maximum distance to the next connector line when to select the connector
+ *  \return id and kind of element-part at the given position. The id is invalid if there is no element at the given position.
+ */
+layout_subelement_id_t gui_sketch_card_private_get_relationship_at_pos ( const gui_sketch_card_t *this_,
+                                                                         int32_t x,
+                                                                         int32_t y,
+                                                                         int32_t snap_distance
+                                                                       );
+
 /*!
  *  \brief draws a single diagram
  *
@@ -147,30 +207,6 @@ static inline data_diagram_t * gui_sketch_card_get_diagram_ptr ( gui_sketch_card
  */
 static inline data_id_t gui_sketch_card_get_diagram_id ( const gui_sketch_card_t *this_ );
 
-/*!
- *  \brief gets the object-id of the object at a given position.
- *
- *  Either it gets the real, de-referenced object at a given position, e.g. a diagram_t or a classifier_t,
- *  or the visible object at a given position, e.g. a diagram_t or a diagramelement_t.
- *
- *  \param this_ pointer to own object attributes
- *  \param x x-position
- *  \param y y-position
- *  \param filter a filter for object types.
- *                E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param out_selected_id the object id at the given location.
- *                         The id is invalid if there is no object at the given location.
- *  \param out_surrounding_id the id of the embracing object at the given location.
- *                            The id is invalid if there is no object embracing the given location.
- */
-static inline void gui_sketch_card_get_object_id_at_pos ( const gui_sketch_card_t *this_,
-                                                          int32_t x,
-                                                          int32_t y,
-                                                          pencil_type_filter_t filter,
-                                                          data_full_id_t* out_selected_id,
-                                                          data_full_id_t* out_surrounding_id
-                                                        );
-
 /*!
  *  \brief gets the order value at a given position
  *
@@ -242,7 +278,23 @@ void gui_sketch_card_move_object_to_order ( gui_sketch_card_t *this_,
                                           );
 
 /*!
- *  \brief lays out the diagram
+ *  \brief gets the dirty_elements_layout flag
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return true if the elements on this this sketch card need to be re-layouted
+ */
+static inline bool gui_sketch_card_needs_layout( const gui_sketch_card_t *this_ );
+
+/*!
+ *  \brief lays out the elements, resets the dirty_elements_layout flag
+ *
+ *  \param this_ pointer to own object attributes
+ *  \param cr cairo drawing context, needed to determine the font metrics
+ */
+static inline void gui_sketch_card_layout_elements( gui_sketch_card_t *this_, cairo_t *cr );
+
+/*!
+ *  \brief lays out the diagram (grid and elements)
  *
  *  This method may be called even if gui_sketch_card_is_valid() is false.
  *
@@ -251,6 +303,14 @@ void gui_sketch_card_move_object_to_order ( gui_sketch_card_t *this_,
  */
 static inline void gui_sketch_card_do_layout( gui_sketch_card_t *this_, cairo_t *cr );
 
+/*!
+ *  \brief gets the layouted visible_set
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return visible_set containing the layouter elements on this this sketch card
+ */
+static inline const layout_visible_set_t * gui_sketch_card_get_visible_set( const gui_sketch_card_t *this_ );
+
 /*!
  *  \brief determines the highest list order of relationships in the current diagram.
  *
