@@ -22,26 +22,28 @@ struct gui_file_export_dialog_struct {
 
     io_exporter_t file_exporter;  /*!<  own instance of io_exporter_t */
 
+    GtkWindow *parent_window;  /*!< pointer to parent window, needed for modal dialogs */
     gui_simple_message_to_user_t *message_to_user;  /*!< pointer to external gui_simple_message_to_user_t */
 
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
     GtkWidget *export_file_chooser;  /*!< pointer to instance of a file chooser for export */
+#else
+    GtkFileDialog *export_file_dialog;  /*!< pointer to instance of a file dialog for export */
+#endif
 
-    //GtkWidget *format_asciidoc;  /*!< pointer to checkbox for export-format asciidoc */
     GtkWidget *format_docbook;  /*!< pointer to checkbox for export-format docbook */
-    //GtkWidget *format_doxygen;  /*!< pointer to checkbox for export-format doxygen */
-    //GtkWidget *format_latex;  /*!< pointer to checkbox for export-format latex */
-    //GtkWidget *format_rtf;  /*!< pointer to checkbox for export-format rtf */
     GtkWidget *format_pdf;  /*!< pointer to checkbox for export-format pdf */
     GtkWidget *format_png;  /*!< pointer to checkbox for export-format png */
     GtkWidget *format_ps;  /*!< pointer to checkbox for export-format ps */
     GtkWidget *format_svg;  /*!< pointer to checkbox for export-format svg */
     GtkWidget *format_txt;  /*!< pointer to checkbox for export-format txt */
-    GtkWidget *format_xhtml;  /*!< pointer to checkbox for export-format xhtml */
+    GtkWidget *format_html;  /*!< pointer to checkbox for export-format html */
     GtkWidget *format_xmi2;  /*!< pointer to checkbox for export-format xmi version 2.x */
     GtkWidget *format_json;  /*!< pointer to checkbox for export-format json */
 
     GtkWidget *diagram_set_label;  /*!< the label for filetype-sets */
     GtkWidget *document_label;  /*!< the label for document-types */
+    GtkButton *export_button;  /*!< the export button that triggers the directory chooser */
     GtkWidget *options_layout;  /*!< the grid layout container for the export options */
 };
 
@@ -70,6 +72,20 @@ void gui_file_export_dialog_init( gui_file_export_dialog_t *this_,
  */
 void gui_file_export_dialog_destroy( gui_file_export_dialog_t *this_ );
 
+/*!
+ *  \brief returns the file options container showing the type selection.
+ *
+ *  This container can be displayed in the main window.
+ *
+ *  \param this_ pointer to own object attributes
+ */
+GtkWidget *gui_file_export_dialog_get_options( gui_file_export_dialog_t *this_ );
+
+/*!
+ *  \brief callback that informs that the export-to-folder button was pressed
+ */
+void gui_file_export_dialog_export_btn_callback( GtkWidget* button, gpointer data );
+
 /*!
  *  \brief shows the file export dialog
  *
@@ -77,11 +93,25 @@ void gui_file_export_dialog_destroy( gui_file_export_dialog_t *this_ );
  */
 void gui_file_export_dialog_show( gui_file_export_dialog_t *this_ );
 
+#if (( GTK_MAJOR_VERSION == 4 )&&( GTK_MINOR_VERSION < 10 ))
+
 /*!
- *  \brief callback function of the GtkDialog
+ *  \brief callback function of the old GtkDialog
  */
 void gui_file_export_dialog_response_callback( GtkDialog *dialog, gint response_id, gpointer user_data );
 
+#else  /* GTK >= 4.10 */
+
+/*!
+ *  \brief callback function of the 4.10 GtkFileDialog
+ */
+void gui_file_export_dialog_async_ready_callback( GObject* source_object,
+                                                  GAsyncResult* res,
+                                                  gpointer user_data
+                                                );
+
+#endif  /* GTK ? 4.10 */
+
 #endif  /* GUI_FILE_EXPORT_DIALOG_H */
 
 
