@@ -101,53 +101,37 @@ void gui_toolbox_set_selected_tool( gui_toolbox_t *this_, gui_tool_t tool )
     {
         case GUI_TOOL_NAVIGATE:
         {
-#if ( GTK_MAJOR_VERSION >= 4 )
             gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( (*this_).tool_navigate ), true );
             gui_simple_message_to_user_hide( (*this_).message_to_user );
             (*this_).selected_tool = GUI_TOOL_NAVIGATE;
             gui_toolbox_private_notify_listeners( this_ );
-#else
-            gtk_toggle_tool_button_set_active( GTK_TOGGLE_TOOL_BUTTON( (*this_).tool_navigate ), true );
-#endif
         }
         break;
 
         case GUI_TOOL_EDIT:
         {
-#if ( GTK_MAJOR_VERSION >= 4 )
             gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( (*this_).tool_edit ), true );
             gui_simple_message_to_user_hide( (*this_).message_to_user );
             (*this_).selected_tool = GUI_TOOL_EDIT;
             gui_toolbox_private_notify_listeners( this_ );
-#else
-            gtk_toggle_tool_button_set_active( GTK_TOGGLE_TOOL_BUTTON( (*this_).tool_edit ), true );
-#endif
         }
         break;
 
         case GUI_TOOL_SEARCH:
         {
-#if ( GTK_MAJOR_VERSION >= 4 )
             gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( (*this_).tool_search ), true );
             gui_simple_message_to_user_hide( (*this_).message_to_user );
             (*this_).selected_tool = GUI_TOOL_SEARCH;
             gui_toolbox_private_notify_listeners( this_ );
-#else
-            gtk_toggle_tool_button_set_active( GTK_TOGGLE_TOOL_BUTTON( (*this_).tool_search ), true );
-#endif
         }
         break;
 
         case GUI_TOOL_CREATE:
         {
-#if ( GTK_MAJOR_VERSION >= 4 )
             gtk_toggle_button_set_active( GTK_TOGGLE_BUTTON( (*this_).tool_create ), true );
             gui_simple_message_to_user_hide( (*this_).message_to_user );
             (*this_).selected_tool = GUI_TOOL_CREATE;
             gui_toolbox_private_notify_listeners( this_ );
-#else
-            gtk_toggle_tool_button_set_active( GTK_TOGGLE_TOOL_BUTTON( (*this_).tool_create ), true );
-#endif
         }
         break;
 
@@ -715,14 +699,11 @@ void gui_toolbox_undo_btn_callback( GtkWidget* button, gpointer data )
     U8_TRACE_END();
 }
 
-#if ( GTK_MAJOR_VERSION >= 4 )
 gboolean gui_toolbox_undo_shortcut_callback( GtkWidget* widget, GVariant* args, gpointer user_data )
 {
     gui_toolbox_undo_btn_callback( widget, user_data );
     return TRUE;
 }
-#else
-#endif
 
 void gui_toolbox_redo_btn_callback( GtkWidget* button, gpointer data )
 {
@@ -760,7 +741,6 @@ void gui_toolbox_redo_btn_callback( GtkWidget* button, gpointer data )
     U8_TRACE_END();
 }
 
-#if ( GTK_MAJOR_VERSION >= 4 )
 /*!
  *  \brief callback that informs that the redo shortcut was activated
  */
@@ -769,8 +749,6 @@ gboolean gui_toolbox_redo_shortcut_callback( GtkWidget* widget, GVariant* args,
     gui_toolbox_redo_btn_callback( widget, user_data );
     return TRUE;
 }
-#else
-#endif
 
 void gui_toolbox_private_notify_listeners( gui_toolbox_t *this_ )
 {
