@@ -50,7 +50,7 @@ void gui_sketch_area_init( gui_sketch_area_t *this_,
     gui_sketch_nav_tree_init( &((*this_).nav_tree), resources, &((*this_).texture_downloader) );
     gui_sketch_result_list_init( &((*this_).result_list), resources, &((*this_).texture_downloader) );
     gui_sketch_drag_state_init ( &((*this_).drag_state) );
-    gui_sketch_overlay_init( &((*this_).overlay) );
+    gui_sketch_card_painter_init( &((*this_).card_overlay) );
     gui_sketch_background_init( &((*this_).background), resources, &((*this_).texture_downloader) );
     gui_sketch_object_creator_init ( &((*this_).object_creator), controller, db_reader, message_to_user );
 
@@ -108,7 +108,7 @@ void gui_sketch_area_destroy( gui_sketch_area_t *this_ )
 
     /* destroy instances of own objects */
     gui_sketch_object_creator_destroy ( &((*this_).object_creator) );
-    gui_sketch_overlay_destroy( &((*this_).overlay) );
+    gui_sketch_card_painter_destroy( &((*this_).card_overlay) );
     gui_sketch_background_destroy( &((*this_).background) );
     gui_sketch_drag_state_destroy ( &((*this_).drag_state) );
     gui_sketch_texture_destroy( &((*this_).texture_downloader) );
@@ -485,9 +485,9 @@ void gui_sketch_area_private_layout_subwidgets ( gui_sketch_area_t *this_, shape
         shape_int_rectangle_t cards_bounds;
         shape_int_rectangle_init( &cards_bounds, cards_left, top, cards_width, height );
         gui_sketch_card_layouter_t cards_layouter;
-        gui_sketch_card_layouter_init ( &cards_layouter, &cards_bounds );
-        gui_sketch_card_layouter_layout ( &cards_layouter, selected_tool, &((*this_).cards[0]), (*this_).card_num, cr );
-        gui_sketch_card_layouter_destroy ( &cards_layouter );
+        gui_sketch_card_layouter_init( &cards_layouter, &cards_bounds );
+        gui_sketch_card_layouter_layout( &cards_layouter, selected_tool, &((*this_).cards[0]), (*this_).card_num, cr );
+        gui_sketch_card_layouter_destroy( &cards_layouter );
     }
 
     /* layout background */
@@ -558,20 +558,33 @@ void gui_sketch_area_private_draw_subwidgets ( gui_sketch_area_t *this_, shape_i
     /* draw all cards, backwards */
     for ( signed int card_idx = (*this_).card_num-1; card_idx >= 0; card_idx -- )
     {
-        gui_sketch_card_draw( &((*this_).cards[card_idx]), (*this_).marker, cr );
+        gui_sketch_card_t *card = &((*this_).cards[card_idx]);
+        /* lazy layouting: only re-calulate positions when these are needed: */
+        if ( gui_sketch_card_needs_layout( card ) )
+        {
+            gui_sketch_card_layout_elements( card, cr );
+        }
+
+        gui_sketch_card_painter_draw_paper( &((*this_).card_overlay),
+                                            selected_tool,
+                                            &((*this_).drag_state),
+                                            card,
+                                            cr
+                                          );
+        gui_sketch_card_draw( card, (*this_).marker, cr );
     }
 
     /* overlay tool-helper lines */
     const int32_t mouse_x = gui_sketch_drag_state_get_to_x( &((*this_).drag_state) );
     const int32_t mouse_y = gui_sketch_drag_state_get_to_y( &((*this_).drag_state) );
-    gui_sketch_overlay_draw( &((*this_).overlay),
-                             selected_tool,
-                             &((*this_).drag_state),
-                             gui_sketch_area_private_get_card_at_pos ( this_, mouse_x, mouse_y ),
-                             &((*this_).nav_tree),
-                             (*this_).marker,
-                             cr
-                           );
+    gui_sketch_card_painter_draw_overlay( &((*this_).card_overlay),
+                                          selected_tool,
+                                          &((*this_).drag_state),
+                                          gui_sketch_area_private_get_card_at_pos ( this_, mouse_x, mouse_y ),
+                                          (*this_).marker,
+                                          cr
+                                        );
+    gui_sketch_nav_tree_draw_overlay( &((*this_).nav_tree), &((*this_).drag_state) , cr );
 
     U8_TRACE_END();
 }
@@ -717,13 +730,13 @@ void gui_sketch_area_motion_notify( gui_sketch_area_t *this_, int x, int y )
             {
                 data_full_id_t object_under_mouse;
                 data_id_t diag_id;
-                gui_sketch_area_private_get_object_id_at_pos( this_,
-                                                              x,
-                                                              y,
-                                                              PENCIL_TYPE_FILTER_LIFELINE,
-                                                              &object_under_mouse,
-                                                              &diag_id
-                                                            );
+                gui_sketch_area_private_get_element_id_at_pos( this_,
+                                                               x,
+                                                               y,
+                                                               true /* FILTER_LIFELINE */,
+                                                               &object_under_mouse,
+                                                               &diag_id
+                                                             );
                 const data_id_t object_highlighted
                     = gui_marked_set_get_highlighted( (*this_).marker );
                 const data_id_t mouseover_element
@@ -745,25 +758,34 @@ void gui_sketch_area_motion_notify( gui_sketch_area_t *this_, int x, int y )
 
         case GUI_TOOL_CREATE:
         {
-            data_full_id_t object_under_mouse;
-            data_id_t diag_id;
-            gui_sketch_area_private_get_object_id_at_pos( this_,
-                                                          x,
-                                                          y,
-                                                          PENCIL_TYPE_FILTER_NONE,
-                                                          &object_under_mouse,
-                                                          &diag_id
-                                                        );
-            const data_id_t classifier_under_mouse
-                = data_full_id_get_primary_id( &object_under_mouse );
+            const gui_sketch_card_t *const target_card = gui_sketch_area_private_get_card_at_pos ( this_, x, y );
+            const layout_subelement_id_t element_id
+                = ( NULL == target_card )
+                ? LAYOUT_SUBELEMENT_ID_VOID
+                : gui_sketch_card_get_element_at_pos( target_card, x, y, false /* FILTER_LIFELINE */ );
+            const data_id_t diagram_id
+                = ( NULL == target_card )
+                ? DATA_ID_VOID
+                : gui_sketch_card_get_diagram_id( target_card );
+            const data_full_id_t *const element_under_mouse_full
+                = layout_subelement_id_get_id_const( &element_id );  /* may return VOID */
+            const layout_subelement_kind_t element_under_mouse_kind
+                = layout_subelement_id_get_kind( &element_id );  /* may return VOID */
+            const data_id_t element_under_mouse
+                = data_full_id_get_primary_id( element_under_mouse_full );
 
-            const data_id_t object_highlighted
+            const data_id_t element_highlighted
                 = gui_marked_set_get_highlighted( (*this_).marker );
-            if ( ! data_id_equals( &classifier_under_mouse, &object_highlighted ) )
+            const layout_subelement_kind_t element_highlighted_kind
+                = gui_marked_set_get_highlighted_kind( (*this_).marker );
+            const bool highlighted_element_changed
+                = ( ! data_id_equals( &element_under_mouse, &element_highlighted ) )
+                || ( element_under_mouse_kind != element_highlighted_kind );
+            if ( highlighted_element_changed )
             {
-                if ( data_id_is_valid( &classifier_under_mouse ) || data_id_is_valid( &object_highlighted ) )
+                if ( data_id_is_valid( &element_under_mouse ) || data_id_is_valid( &element_highlighted ) )
                 {
-                    gui_marked_set_set_highlighted( (*this_).marker, classifier_under_mouse, diag_id );
+                    gui_marked_set_set_highlighted_subelement( (*this_).marker, &element_id, diagram_id );
 
                     /* mark dirty rect */
                     gtk_widget_queue_draw( (*this_).drawing_area );
@@ -957,13 +979,13 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
             /* determine the focused object */
             data_full_id_t focused_object;
             data_id_t diag_id;
-            gui_sketch_area_private_get_object_id_at_pos( this_,
-                                                          x,
-                                                          y,
-                                                          PENCIL_TYPE_FILTER_LIFELINE,
-                                                          &focused_object,
-                                                          &diag_id
-                                                        );
+            gui_sketch_area_private_get_element_id_at_pos( this_,
+                                                           x,
+                                                           y,
+                                                           true /* FILTER_LIFELINE */,
+                                                           &focused_object,
+                                                           &diag_id
+                                                         );
             data_full_id_trace( &focused_object );
 
             /* update drag state */
@@ -1033,42 +1055,37 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
             else
             {
                 /* determine the object at click location */
-                data_full_id_t clicked_object;
-                data_full_id_t surrounding_object;
-                data_id_t diag_id;
-                gui_sketch_area_private_get_object_ids_at_pos( this_,
-                                                               x,
-                                                               y,
-                                                               PENCIL_TYPE_FILTER_NONE,
-                                                               &clicked_object,
-                                                               &surrounding_object,
-                                                               &diag_id
-                                                             );
-                data_full_id_trace( &clicked_object );
-                data_full_id_trace( &surrounding_object );
-                const data_id_t *const clicked_classifier
-                    = data_full_id_get_secondary_id_ptr( &clicked_object );
-                const data_id_t *const surrounding_classifier
-                    = data_full_id_get_secondary_id_ptr( &surrounding_object );
-
-                if ( DATA_TABLE_CLASSIFIER == data_id_get_table( clicked_classifier ) )
+                const data_id_t diagram_id = gui_sketch_card_get_diagram_id( target_card );
+                const layout_subelement_id_t element_id
+                    = gui_sketch_card_get_element_at_pos( target_card, x, y, false /* FILTER_LIFELINE */ );
+                const data_full_id_t *const clicked_object
+                    = layout_subelement_id_get_id_const( &element_id );
+                data_full_id_trace( clicked_object );
+                const layout_subelement_kind_t kind
+                    = layout_subelement_id_get_kind( &element_id );
+                if ( kind != LAYOUT_SUBELEMENT_KIND_SPACE )
                 {
                     /* update drag state */
-                    gui_sketch_drag_state_start_dragging_when_move ( &((*this_).drag_state), clicked_object );
+                    gui_sketch_drag_state_start_dragging_when_move ( &((*this_).drag_state), *clicked_object );
 
-                    /* set focused object (either a diagramelement or a feature) */
-                    gui_marked_set_set_focused( (*this_).marker, clicked_object, diag_id );
+                    /* set focused object (either a diagramelement or a feature - but not a lifeline!) */
+                    const layout_subelement_id_t filtered_element_id
+                        = gui_sketch_card_get_element_at_pos( target_card, x, y, true /* FILTER_LIFELINE */ );
+                    const data_full_id_t *const clicked_filtered_object
+                        = layout_subelement_id_get_id_const( &filtered_element_id );
+                    gui_marked_set_set_focused( (*this_).marker, *clicked_filtered_object, diagram_id );
                 }
-                else /* clicked either into inner space of a classifier or at a relation or outside any classifier */
+                else /* clicked either into inner space of a classifier or of a diagram */
                 {
                     /* stop dragging */
                     gui_sketch_drag_state_stop_dragging ( &((*this_).drag_state) );
 
-                    /* create a new classifier */
-                    const data_diagram_t *const target_diag = gui_sketch_card_get_diagram_ptr ( target_card );
-                    const data_row_id_t selected_diagram_id = data_diagram_get_row_id( target_diag );
-                    U8_TRACE_INFO_INT( "selected_diagram_id:", selected_diagram_id );
+                    /* get data */
+                    const data_id_t *const surrounding_element
+                        = data_full_id_get_primary_id_const( clicked_object );
+                    assert( data_id_is_valid( surrounding_element ) );
 
+                    /* create a new classifier */
                     data_id_t dummy_classifier;
                     data_id_init( &dummy_classifier, DATA_TABLE_CLASSIFIER, DATA_ROW_ID_VOID );
                     layout_order_t layout_order = gui_sketch_card_get_order_at_pos( target_card, dummy_classifier, x, y );
@@ -1080,11 +1097,15 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
                     u8_error_t c_result;
                     data_row_id_t new_diagele_id;
                     data_row_id_t new_classifier_id;
-                    if ( DATA_TABLE_CLASSIFIER == data_id_get_table( surrounding_classifier ) )
+                    if ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( surrounding_element ) )
                     {
+                        const data_id_t *const surrounding_classifier
+                            = data_full_id_get_secondary_id_const( clicked_object );
+                        assert( data_id_is_valid( surrounding_classifier ) );
+
                         data_row_id_t new_relationship_id;
                         c_result = gui_sketch_object_creator_create_classifier_as_child( &((*this_).object_creator),
-                                                                                         selected_diagram_id,
+                                                                                         data_id_get_row_id( &diagram_id ),
                                                                                          data_id_get_row_id( surrounding_classifier ),
                                                                                          x_order,
                                                                                          y_order,
@@ -1095,8 +1116,9 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
                     }
                     else
                     {
+                        assert( DATA_TABLE_DIAGRAM == data_id_get_table( surrounding_element ) );
                         c_result = gui_sketch_object_creator_create_classifier( &((*this_).object_creator),
-                                                                                selected_diagram_id,
+                                                                                data_id_get_row_id( &diagram_id ),
                                                                                 x_order,
                                                                                 y_order,
                                                                                 &new_diagele_id,
@@ -1122,7 +1144,7 @@ void gui_sketch_area_button_press( gui_sketch_area_t *this_, int x, int y )
                         /* set focused object and notify listener */
                         const data_full_id_t focused_object
                             = DATA_FULL_ID( DATA_TABLE_DIAGRAMELEMENT, new_diagele_id, new_classifier_id );
-                        gui_marked_set_set_focused( (*this_).marker, focused_object, diag_id );
+                        gui_marked_set_set_focused( (*this_).marker, focused_object, diagram_id );
                         gui_marked_set_clear_selected_set( (*this_).marker );
 
                         U8_TRACE_INFO_INT( "new_classifier_id:", new_classifier_id );
@@ -1333,11 +1355,11 @@ void gui_sketch_area_button_release( gui_sketch_area_t *this_, int x, int y )
         {
             U8_TRACE_INFO("GUI_TOOL_EDIT");
 
-            if ( gui_sketch_drag_state_is_dragging ( &((*this_).drag_state) ) )
+            if ( gui_sketch_drag_state_is_dragging( &((*this_).drag_state) ) )
             {
                 /* which object is selected? */
                 const data_full_id_t *const dragged_object
-                    = gui_sketch_drag_state_get_dragged_object_ptr ( &((*this_).drag_state) );
+                    = gui_sketch_drag_state_get_dragged_object_ptr( &((*this_).drag_state) );
                 const data_id_t dragged_element
                     = data_full_id_get_primary_id( dragged_object );
                 const data_id_t dragged_classifier
@@ -1491,29 +1513,29 @@ void gui_sketch_area_button_release( gui_sketch_area_t *this_, int x, int y )
                 /* which object is at the target location? */
                 data_full_id_t destination_object;
                 data_id_t diag_id;
-                gui_sketch_area_private_get_object_id_at_pos( this_,
-                                                              x,
-                                                              y,
-                                                              PENCIL_TYPE_FILTER_NONE,
-                                                              &destination_object,
-                                                              &diag_id
-                                                            );
+                gui_sketch_area_private_get_element_id_at_pos( this_,
+                                                               x,
+                                                               y,
+                                                               false /* FILTER_LIFELINE */,
+                                                               &destination_object,
+                                                               &diag_id
+                                                             );
                 data_full_id_trace( &destination_object );
                 const data_id_t destination_element
                     = data_full_id_get_primary_id( &destination_object );
                 const data_id_t destination_classifier
                     = data_full_id_get_secondary_id( &destination_object );
 
-                gui_sketch_card_t *target_card = gui_sketch_area_private_get_card_at_pos ( this_, x, y );
+                gui_sketch_card_t *target_card = gui_sketch_area_private_get_card_at_pos( this_, x, y );
                 if ( data_id_is_valid( &dragged_classifier ) && data_id_is_valid( &destination_classifier ) && ( NULL != target_card ))
                 {
                     if ( ( DATA_TABLE_CLASSIFIER == data_id_get_table( &dragged_classifier ) )
                         && ( DATA_TABLE_CLASSIFIER == data_id_get_table( &destination_classifier ) ) )
                     {
                         /* get the diagram type */
-                        const data_diagram_t *const target_diag = gui_sketch_card_get_diagram_ptr ( target_card );
+                        const data_diagram_t *const target_diag = gui_sketch_card_get_diagram_ptr( target_card );
                         assert ( target_diag != NULL );
-                        data_diagram_type_t diag_type = data_diagram_get_diagram_type ( target_diag );
+                        data_diagram_type_t diag_type = data_diagram_get_diagram_type( target_diag );
 
                         /* determine source and destionation */
                         data_row_id_t new_from_classifier_id;
@@ -1588,18 +1610,32 @@ void gui_sketch_area_button_release( gui_sketch_area_t *this_, int x, int y )
             }
             else if ( gui_sketch_drag_state_is_waiting_for_move( &((*this_).drag_state) ) )
             {
-                /* click on classifier without drag */
                 const data_full_id_t *const dragged_object
                     = gui_sketch_drag_state_get_dragged_object_ptr ( &((*this_).drag_state) );
                 const data_id_t dragged_classifier
                     = data_full_id_get_secondary_id( dragged_object );
 
                 const gui_sketch_card_t *const target_card
-                    = gui_sketch_area_private_get_card_at_pos ( this_, x, y );
+                    = gui_sketch_area_private_get_card_at_pos( this_, x, y );
                 if ( data_id_is_valid( &dragged_classifier ) && ( NULL != target_card ) )
                 {
+                    /* click on classifier without drag */
+                    const layout_subelement_id_t subelement_id
+                        = gui_sketch_card_get_element_at_pos( target_card, x, y, false /* FILTER_LIFELINE */ );
+                    const data_full_id_t *const full_element
+                        = layout_subelement_id_get_id_const( &subelement_id );
+                    data_full_id_trace( full_element );
+                    const data_id_t clicked_element
+                        = data_full_id_get_primary_id( full_element );
+                    const data_id_t clicked_classifier
+                        = data_full_id_get_secondary_id( full_element );
+                    const bool is_diagele
+                        = ( DATA_TABLE_DIAGRAMELEMENT == data_id_get_table( &clicked_element ) );
+                    const bool is_outline
+                        = ( LAYOUT_SUBELEMENT_KIND_OUTLINE == layout_subelement_id_get_kind( &subelement_id ) );
+
                     const data_id_t diag_id = gui_sketch_card_get_diagram_id( target_card );
-                    if ( DATA_TABLE_CLASSIFIER == data_id_get_table( &dragged_classifier ) )
+                    if ( is_diagele && is_outline && ( DATA_TABLE_CLASSIFIER == data_id_get_table( &clicked_classifier ) ) )
                     {
                         /* get the diagram type */
                         const data_diagram_t *const target_diag
@@ -1608,11 +1644,11 @@ void gui_sketch_area_button_release( gui_sketch_area_t *this_, int x, int y )
                         const data_diagram_type_t diag_type = data_diagram_get_diagram_type ( target_diag );
 
                         /* determine id of classifier to which the clicked object belongs */
-                        const data_row_id_t classifier_id = data_id_get_row_id( &dragged_classifier );
+                        const data_row_id_t classifier_id = data_id_get_row_id( &clicked_classifier );
 
                         /* propose a list_order for the feature */
                         const int32_t std_list_order_proposal
-                            = gui_sketch_card_get_highest_feat_list_order( target_card, dragged_classifier ) + 32768;
+                            = gui_sketch_card_get_highest_feat_list_order( target_card, clicked_classifier ) + 32768;
                         int32_t port_list_order_proposal = 0;
                         {
                             data_feature_init_new( &((*this_).private_temp_fake_feature),
