@@ -22,8 +22,8 @@ enum io_file_format_enum {
     IO_FILE_FORMAT_PNG     = 0x00008,  /*!< portable network graphics */
     IO_FILE_FORMAT_TXT     = 0x00010,  /*!< utf8 encoded text */
     IO_FILE_FORMAT_DOCBOOK = 0x00100,  /*!< docbook */
-    IO_FILE_FORMAT_HTML   = 0x00200,  /*!< xhtml */
-    IO_FILE_FORMAT_CSS     = 0x00400,  /*!< css for xhtml */
+    IO_FILE_FORMAT_HTML   = 0x00200,  /*!< html */
+    IO_FILE_FORMAT_CSS     = 0x00400,  /*!< css for html */
     IO_FILE_FORMAT_XMI2    = 0x01000,  /*!< xmi version 2.5.1 */
     IO_FILE_FORMAT_JSON    = 0x10000,  /*!< json; json-ld: https://www.w3.org/TR/json-ld/ */
     IO_FILE_FORMAT_SCHEMA  = 0x20000,  /*!< json schema of Internet Engineering Task Force */
@@ -37,7 +37,7 @@ void io_file_format_to_string( io_file_format_t format_set, utf8stringbuf_t out_
 
 
 /*
-Copyright 2016-2023 Andreas Warnke
+Copyright 2016-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
