@@ -13,8 +13,8 @@
  *  Sink: universal_output_stream_t
  */
 
-#include "xml/xml_writer.h"
-#include "md/md_filter.h"
+#include "format/io_xml_writer.h"
+#include "format/io_md_writer.h"
 #include "storage/data_database_reader.h"
 #include "utf8stringbuf/utf8stringbuf.h"
 #include "u8stream/universal_output_stream.h"
@@ -24,7 +24,7 @@
  *  \brief attributes of the xmi_atom_writer_t
  */
 struct xmi_atom_writer_struct {
-    xml_writer_t *xml_writer;  /*!< pointer to external xml writer */
+    io_xml_writer_t *xml_writer;  /*!< pointer to external xml writer */
 };
 
 typedef struct xmi_atom_writer_struct xmi_atom_writer_t;
@@ -36,7 +36,7 @@ typedef struct xmi_atom_writer_struct xmi_atom_writer_t;
  *  \param out_writer output stream where to write the generated output to
  */
 void xmi_atom_writer_init( xmi_atom_writer_t *this_,
-                           xml_writer_t *out_writer
+                           io_xml_writer_t *out_writer
                          );
 
 /*!
@@ -66,7 +66,7 @@ u8_error_t xmi_atom_writer_write_xmi_comment( xmi_atom_writer_t *this_,
  *
  *  \param this_ pointer to own object attributes
  *  \param element_id id which to encode for xmi
- *  \return U8_ERROR_NONE in case of success
+ *  \return U8_ERROR_NONE in case of success, U8_ERROR_PARAM_MISSING if element_id is not valid
  */
 u8_error_t xmi_atom_writer_encode_xmi_id( xmi_atom_writer_t *this_,
                                           data_id_t element_id
@@ -152,7 +152,7 @@ u8_error_t xmi_atom_writer_report_illegal_container( xmi_atom_writer_t *this_,
  */
 u8_error_t xmi_atom_writer_report_illegal_stereotype( xmi_atom_writer_t *this_,
                                                       data_id_t element_id,
-                                                      utf8stringview_t stereotype
+                                                      const utf8stringview_t *stereotype
                                                     );
 
 /*!
@@ -243,7 +243,7 @@ u8_error_t xmi_atom_writer_report_illegal_relationship_end ( xmi_atom_writer_t *
 
 
 /*
-Copyright 2020-2023 Andreas Warnke
+Copyright 2020-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
