@@ -18,7 +18,7 @@
 
 void xmi_interaction_writer_init ( xmi_interaction_writer_t *this_,
                                    data_stat_t *io_export_stat,
-                                   xml_writer_t *out_writer  )
+                                   io_xml_writer_t *out_writer  )
 {
     U8_TRACE_BEGIN();
     assert( NULL != io_export_stat );
@@ -88,40 +88,40 @@ u8_error_t xmi_interaction_writer_start_diagram( xmi_interaction_writer_t *this_
         }
 
         /* write nesting tag */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_START_TAG_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, nesting_property );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
-        xml_writer_increase_indent ( (*this_).xml_writer );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_NL );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_START_TAG_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, nesting_property );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
+        io_xml_writer_increase_indent ( (*this_).xml_writer );
 
         /* write type attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
         /* TODO possibly a uml:Collaboration needs to be placed around the DATA_CLASSIFIER_TYPE_INTERACTION? */
         const char* c_type = xmi_type_converter_get_xmi_type_of_classifier ( &((*this_).xmi_types),
                                                                              parent_type,
                                                                              DATA_CLASSIFIER_TYPE_INTERACTION,  /* fake child type */
                                                                              XMI_SPEC_UML
                                                                            );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, c_type );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
+        export_err |= io_xml_writer_write_xml_enc ( (*this_).xml_writer, c_type );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), diagram_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write name attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_NAME_START );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, diagram_name );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_NAME_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_NAME_START );
+        export_err |= io_xml_writer_write_xml_enc ( (*this_).xml_writer, diagram_name );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_NAME_END );
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_START_TAG_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_START_TAG_END );
 
         /* write real id comment */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_COMMENT_START );
-        export_err |= xml_writer_write_plain_id( (*this_).xml_writer, diagram_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_COMMENT_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_COMMENT_START );
+        export_err |= io_xml_writer_write_plain_id( (*this_).xml_writer, diagram_id );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_COMMENT_END );
 
         /* write description */
         if ( 0 != diagram_descr_len )
@@ -165,11 +165,11 @@ u8_error_t xmi_interaction_writer_end_diagram( xmi_interaction_writer_t *this_,
         }
 
         /* adjust indentation, write end tag */
-        xml_writer_decrease_indent ( (*this_).xml_writer );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_END_TAG_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, nesting_property );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_END_TAG_END );
+        io_xml_writer_decrease_indent ( (*this_).xml_writer );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_NL );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_END_TAG_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, nesting_property );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_END_TAG_END );
     }
 
     U8_TRACE_END_ERR( export_err );
@@ -190,29 +190,29 @@ u8_error_t xmi_interaction_writer_assemble_feature( xmi_interaction_writer_t *th
 
     if ( (*this_).mode == XMI_WRITER_PASS_BASE )
     {
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_START );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, "represents" );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_NL );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_START );
+        export_err |= io_xml_writer_write_xml_enc ( (*this_).xml_writer, "represents" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
 
         /* write type attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "Property" );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "Property" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), feature_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "#ref" );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "#ref" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "type=\"" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "type=\"" );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), reference_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "\" " );
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_END );
     }
 
     U8_TRACE_END_ERR( export_err );
@@ -281,26 +281,26 @@ u8_error_t xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_
                                                                           );
         }
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_START );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, from_type_tag );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_NL );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_START );
+        export_err |= io_xml_writer_write_xml_enc ( (*this_).xml_writer, from_type_tag );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
 
         /* write type attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_SOURCE_END );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_SOURCE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_VALUE_START );
         if ( data_id_is_valid( &from_feature_id ) )
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_feature_id );
@@ -309,15 +309,15 @@ u8_error_t xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), from_classifier_id );
         }
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_END );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_VALUE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), interaction_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "\" " );
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_END );
 
         /* destination */
         /* determine from type tag */
@@ -347,26 +347,26 @@ u8_error_t xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_
                                                                           );
         }
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_NL );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_START );
-        export_err |= xml_writer_write_xml_enc ( (*this_).xml_writer, to_type_tag );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_NL );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_START );
+        export_err |= io_xml_writer_write_xml_enc ( (*this_).xml_writer, to_type_tag );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
 
         /* write type attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_NS_UML );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_TYPE_MSG_OCCURRENCE_SPEC );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_TYPE_END );
 
         /* write id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_START );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), relation_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_TARGET_END );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_ID_FRAGMENT_TARGET_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_XML_ATTR_ID_END );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_START );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, XMI_ELEMENT_PART_PROPERTY_OCCURRENCE_SPEC_COVERED );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_VALUE_START );
         if ( data_id_is_valid( &to_feature_id ) )
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_feature_id );
@@ -375,15 +375,15 @@ u8_error_t xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_
         {
             export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), to_classifier_id );
         }
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_VALUE_END );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_ATTR_SEPARATOR );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_VALUE_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_ATTR_SEPARATOR );
 
         /* write lifeline id attribute */
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "enclosingInteraction=\"" );
         export_err |= xmi_atom_writer_encode_xmi_id( &((*this_).atom_writer), interaction_id );
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, "\" " );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, "\" " );
 
-        export_err |= xml_writer_write_plain ( (*this_).xml_writer, XML_WRITER_EMPTY_TAG_END );
+        export_err |= io_xml_writer_write_plain ( (*this_).xml_writer, IO_XML_WRITER_EMPTY_TAG_END );
 
     }
 
@@ -393,7 +393,7 @@ u8_error_t xmi_interaction_writer_assemble_relationship( xmi_interaction_writer_
 
 
 /*
-Copyright 2020-2023 Andreas Warnke
+Copyright 2020-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
