@@ -26,7 +26,12 @@ static data_row_id_t set_mode_paste_to_root_diag( test_fixture_t *fix );
 test_suite_t io_import_elements_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "io_import_elements_test_get_suite", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "io_import_elements_test_get_suite",
+                     TEST_CATEGORY_UNIT | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "test_reject_duplicates", &test_reject_duplicates );
     return result;
 }
@@ -66,6 +71,7 @@ static void tear_down( test_fixture_t *fix )
     assert( fix != NULL );
     io_import_elements_destroy( &((*fix).elements_importer) );
     utf8stream_writer_destroy( &((*fix).out_writer) );
+    universal_null_output_stream_flush( &((*fix).null_out) );  /* does nothing - except to improve test coverage */
     universal_null_output_stream_destroy( &((*fix).null_out) );
 
     data_stat_destroy( &((*fix).stats) );
