@@ -25,20 +25,12 @@ u8_error_t main_commands_init ( main_commands_t *this_, bool start_gui, int argc
     /* initialize the base libraries: gobject, gio, glib, gdk and gtk */
     if ( start_gui )
     {
-#if ( GTK_MAJOR_VERSION >= 4 )
         gtk_init();
-#else
-        gtk_init( &argc, &argv );
-#endif
         /* if this program was not terminated, gtk init was successful. */
     }
     else
     {
-#if ( GTK_MAJOR_VERSION >= 4 )
         const gboolean success = gtk_init_check();
-#else
-        const gboolean success = gtk_init_check( &argc, &argv );
-#endif
         if ( ! success )
         {
             U8_LOG_WARNING("gtk could not be initialized.");
