@@ -9,6 +9,7 @@
  *  \brief Draws titles and types of relationships
  */
 
+#include "draw/draw_line_breaker.h"
 #include "draw/draw_stereotype_image.h"
 #include "pencil_size.h"
 #include "geometry/geometry_h_align.h"
@@ -17,6 +18,7 @@
 #include "geometry/geometry_dimensions.h"
 #include "data_relationship.h"
 #include "set/data_profile_part.h"
+#include "utf8stream/utf8stream_writemem.h"
 #include <cairo.h>
 #include <stdint.h>
 
@@ -27,6 +29,9 @@
  *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct draw_relationship_label_struct {
+    char text_buffer[ ( DATA_RELATIONSHIP_MAX_NAME_SIZE ) * 4 ];  /*!< x4 because any character may be followed by a 3-byte space */
+    utf8stream_writemem_t text_builder;  /*!< a pair of utf8stream_writer_t and universal_memory_output_stream_t to build an output text */
+    draw_line_breaker_t linebr;  /*!< An object to insert zero-width spaces (a 3 byte utf8 sequence) wherever a linebreak is allowed */
     draw_stereotype_image_t image_renderer;  /*!< own instance of stereotype image renderer */
 };
 
@@ -37,14 +42,14 @@ typedef struct draw_relationship_label_struct draw_relationship_label_t;
  *
  *  \param this_ pointer to own object attributes
  */
-static inline void draw_relationship_label_init( draw_relationship_label_t *this_ );
+void draw_relationship_label_init( draw_relationship_label_t *this_ );
 
 /*!
  *  \brief destroys the draw_relationship_label_t
  *
  *  \param this_ pointer to own object attributes
  */
-static inline void draw_relationship_label_destroy( draw_relationship_label_t *this_ );
+void draw_relationship_label_destroy( draw_relationship_label_t *this_ );
 
 /*!
  *  \brief determines the dimensions of the stereotype and name of the relationship.
@@ -57,7 +62,7 @@ static inline void draw_relationship_label_destroy( draw_relationship_label_t *t
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
  *  \param out_label_dim width and height of the type and name is returned. NULL is not permitted.
  */
-void draw_relationship_label_get_type_and_name_dimensions( const draw_relationship_label_t *this_,
+void draw_relationship_label_get_type_and_name_dimensions( draw_relationship_label_t *this_,
                                                            const data_relationship_t *relationship,
                                                            const data_profile_part_t *profile,
                                                            const geometry_dimensions_t *proposed_bounds,
@@ -78,7 +83,7 @@ void draw_relationship_label_get_type_and_name_dimensions( const draw_relationsh
  *  \param font_layout pango layout object to determine the font metrics in the current cairo drawing context
  *  \param cr the cairo drawing context.
  */
-void draw_relationship_label_draw_type_and_name( const draw_relationship_label_t *this_,
+void draw_relationship_label_draw_type_and_name( draw_relationship_label_t *this_,
                                                  const data_relationship_t *relationship,
                                                  const data_profile_part_t *profile,
                                                  const GdkRGBA *color,
