@@ -13,7 +13,7 @@
 
 #include "pencil_classifier_composer.h"
 #include "pencil_size.h"
-#include "pencil_layout_data.h"
+#include "layout/layout_visible_set.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_h_align.h"
 #include "geometry/geometry_v_align.h"
@@ -34,7 +34,7 @@
  *        It may either be instantiated once and used many times or be instantiated per use.
  */
 struct pencil_classifier_1d_layouter_struct {
-    pencil_layout_data_t *layout_data;  /* pointer to external layout data */
+    layout_visible_set_t *layout_data;  /* pointer to external layout data */
     const data_profile_part_t *profile;  /*!< pointer to an external stereotype-image cache */
     const pencil_size_t *pencil_size;  /*!< pointer to an external pencil_size_t object, defining pen sizes, gap sizes, font sizes and colors */
     const geometry_rectangle_t *diagram_draw_area;  /*!< pointer to an external drawing rectangle containing inner contents of the diagram */
@@ -54,7 +54,7 @@ typedef struct pencil_classifier_1d_layouter_struct pencil_classifier_1d_layoute
  *  \param pencil_size pointer to the pencil_size_t object
  */
 void pencil_classifier_1d_layouter_init( pencil_classifier_1d_layouter_t *this_,
-                                         pencil_layout_data_t *layout_data,
+                                         layout_visible_set_t *layout_data,
                                          const data_profile_part_t *profile,
                                          const pencil_size_t *pencil_size
                                        );
