@@ -16,7 +16,6 @@
 #include "pencil_relationship_painter.h"
 #include "pencil_size.h"
 #include "pencil_error.h"
-#include "filter/pencil_type_filter.h"
 #include "layout/layout_order.h"
 #include "geometry/geometry_rectangle.h"
 #include "geometry/geometry_non_linear_scale.h"
@@ -111,21 +110,6 @@ static inline void pencil_diagram_maker_layout_elements ( pencil_diagram_maker_t
                                                           cairo_t *cr
                                                         );
 
-/*!
- *  \brief draws markers where diagram elements and relationships overlap
- *
- *  This function may be called only after a call to pencil_diagram_maker_layout_elements()
- *
- *  \param this_ pointer to own object attributes
- *  \param io_layout_stat pointer to already initialized statistics object where layouting statistics are added
- *                        or NULL if no statistics of interest
- *  \param cr a cairo drawing context, used to determine the font metrics in the given drawing context
- */
-void pencil_diagram_maker_show_overlaps ( pencil_diagram_maker_t *this_,
-                                          data_stat_t *io_layout_stat,
-                                          cairo_t *cr
-                                        );
-
 /*!
  *  \brief draws the chosen diagram contents into the diagram_bounds area of the cairo drawing context
  *
@@ -198,28 +182,6 @@ void pencil_diagram_maker_private_draw_relationships ( pencil_diagram_maker_t *t
                                                        cairo_t *cr
                                                      );
 
-/*!
- *  \brief gets the object-id of the object at a given position
- *
- *  \param this_ pointer to own object attributes
- *  \param x x-position
- *  \param y y-position
- *  \param filter a filter for object types.
- *                E.g. PENCIL_TYPE_FILTER_LIFELINE will return the classifier instead of the lifeline-feature.
- *  \param out_selected_id the object id at the given location.
- *                         The id is invalid if there is no object at the given location.
- *  \param out_surrounding_id the id of the embracing object at the given location.
- *                            The id is invalid if there is no object at the given location.
- *  \return PENCIL_ERROR_OUT_OF_BOUNDS if the given position x, y is not in the diagram.
- */
-static inline pencil_error_t pencil_diagram_maker_get_object_id_at_pos ( const pencil_diagram_maker_t *this_,
-                                                                         double x,
-                                                                         double y,
-                                                                         pencil_type_filter_t filter,
-                                                                         data_full_id_t* out_selected_id,
-                                                                         data_full_id_t* out_surrounding_id
-                                                                       );
-
 /*!
  *  \brief determines if the given position is on a grid line
  *
@@ -295,18 +257,12 @@ pencil_error_t pencil_diagram_maker_get_feature_order_at_pos ( const pencil_diag
                                                                layout_order_t* out_layout_order
                                                              );
 
-
 /*!
- *  \brief draws rectangles for pencil_diagram_maker_show_overlaps
+ *  \brief returns the layout_visible_set_t object
  *
- *  \param data pointer that is passed to overlap_callback
- *  \param rect_a pointer to a rectangle that overlaps with rect_b
- *  \param rect_b pointer to a rectangle that overlaps with rect_a
+ *  \param this_ pointer to own object attributes
  */
-void pencil_diagram_maker_draw_rects_callback ( void *data,
-                                                const geometry_rectangle_t *rect_a,
-                                                const geometry_rectangle_t *rect_b
-                                              );
+static inline const layout_visible_set_t *pencil_diagram_maker_get_layout_data_const ( const pencil_diagram_maker_t *this_ );
 
 #include "pencil_diagram_maker.inl"
 
