@@ -7,58 +7,6 @@
 #include <stdlib.h>
 #include <math.h>
 
-void pencil_diagram_maker_draw_rects_callback ( void *data,
-                                                const geometry_rectangle_t *rect_a,
-                                                const geometry_rectangle_t *rect_b )
-{
-    assert( NULL != data );
-    assert( NULL != rect_a );
-    assert( NULL != rect_b );
-    cairo_t *cr = data;
-    cairo_set_source_rgba( cr, 1.0, 0.8, 0.8, 1.0 );
-    cairo_rectangle ( cr,
-                      geometry_rectangle_get_left ( rect_a ),
-                      geometry_rectangle_get_top ( rect_a ),
-                      geometry_rectangle_get_width ( rect_a ),
-                      geometry_rectangle_get_height ( rect_a )
-                    );
-    cairo_rectangle ( cr,
-                      geometry_rectangle_get_left ( rect_b ),
-                      geometry_rectangle_get_top ( rect_b ),
-                      geometry_rectangle_get_width ( rect_b ),
-                      geometry_rectangle_get_height ( rect_b )
-                    );
-    cairo_stroke (cr);
-
-    geometry_rectangle_t isect;
-    const int err_no_intersect = geometry_rectangle_init_by_intersect( &isect, rect_a, rect_b );
-    if ( err_no_intersect == 0 )
-    {
-        cairo_rectangle ( cr,
-                        geometry_rectangle_get_left ( &isect ),
-                        geometry_rectangle_get_top ( &isect ),
-                        geometry_rectangle_get_width ( &isect ),
-                        geometry_rectangle_get_height ( &isect )
-                        );
-        cairo_fill (cr);
-        geometry_rectangle_destroy( &isect );
-    }
-}
-
-void pencil_diagram_maker_show_overlaps ( pencil_diagram_maker_t *this_,
-                                          data_stat_t *io_layout_stat,
-                                          cairo_t *cr )
-{
-    data_stat_t dummy_layout_stats;
-    data_stat_init( &dummy_layout_stats );
-    pencil_layout_data_analyze( pencil_layouter_get_layout_data_const( &((*this_).layouter) ),
-                                (io_layout_stat == NULL) ? &dummy_layout_stats : io_layout_stat,
-                                pencil_diagram_maker_draw_rects_callback,
-                                cr
-                              );
-    data_stat_destroy( &dummy_layout_stats );
-}
-
 void pencil_diagram_maker_draw ( pencil_diagram_maker_t *this_,
                                  data_id_t mark_focused,
                                  data_id_t mark_highlighted,
@@ -73,10 +21,10 @@ void pencil_diagram_maker_draw ( pencil_diagram_maker_t *this_,
     layout = pango_cairo_create_layout (cr);
 
     /* get layout data object */
-    const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
+    const layout_visible_set_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
 
     /* get diagram bounds */
-    const layout_diagram_t *const diagram_layout = pencil_layout_data_get_diagram_const( layout_data );
+    const layout_diagram_t *const diagram_layout = layout_visible_set_get_diagram_const( layout_data );
     const geometry_rectangle_t *const diagram_bounds = layout_diagram_get_bounds_const ( diagram_layout );
     double width = geometry_rectangle_get_width ( diagram_bounds );
     double height = geometry_rectangle_get_height ( diagram_bounds );
@@ -142,13 +90,13 @@ void pencil_diagram_maker_private_draw_classifiers ( pencil_diagram_maker_t *thi
     assert( NULL != mark_selected );
     assert( NULL != cr );
 
-    const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
+    const layout_visible_set_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
 
     /* iterate over all classifiers */
-    const uint32_t count = pencil_layout_data_get_visible_classifier_count ( layout_data );
+    const uint32_t count = layout_visible_set_get_visible_classifier_count ( layout_data );
     for ( uint32_t index = 0; index < count; index ++ )
     {
-        const layout_visible_classifier_t *const classifier_layout = pencil_layout_data_get_visible_classifier_const( layout_data, index );
+        const layout_visible_classifier_t *const classifier_layout = layout_visible_set_get_visible_classifier_const( layout_data, index );
 
         const pencil_size_t *const pencil_size = pencil_layouter_get_pencil_size_const( &((*this_).layouter) );
 
@@ -179,14 +127,14 @@ void pencil_diagram_maker_private_draw_features ( pencil_diagram_maker_t *this_,
     assert( NULL != mark_selected );
     assert( NULL != cr );
 
-    const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
+    const layout_visible_set_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
 
     /* iterate over all features */
-    const uint32_t count = pencil_layout_data_get_feature_count ( layout_data );
+    const uint32_t count = layout_visible_set_get_feature_count ( layout_data );
     for ( uint32_t f_idx = 0; f_idx < count; f_idx ++ )
     {
         /* get feature */
-        const layout_feature_t *const the_feature = pencil_layout_data_get_feature_const( layout_data, f_idx );
+        const layout_feature_t *const the_feature = layout_visible_set_get_feature_const( layout_data, f_idx );
 
         /* determine display flags of diagramelement */
         const layout_visible_classifier_t *const classifier_layout = layout_feature_get_classifier_const ( the_feature );
@@ -221,13 +169,13 @@ void pencil_diagram_maker_private_draw_relationships ( pencil_diagram_maker_t *t
     assert( NULL != mark_selected );
     assert( NULL != cr );
 
-    const pencil_layout_data_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
+    const layout_visible_set_t *const layout_data = pencil_layouter_get_layout_data_const ( &((*this_).layouter) );
 
-    const uint32_t rel_count = pencil_layout_data_get_relationship_count ( layout_data );
+    const uint32_t rel_count = layout_visible_set_get_relationship_count ( layout_data );
     for ( uint32_t index = 0; index < rel_count; index ++ )
     {
         pencil_visibility_t show_relation;
-        const layout_relationship_t *const relationship_layout = pencil_layout_data_get_relationship_const ( layout_data, index );
+        const layout_relationship_t *const relationship_layout = layout_visible_set_get_relationship_const ( layout_data, index );
         const data_relationship_t *const the_relationship = layout_relationship_get_data_const ( relationship_layout );
         show_relation = layout_relationship_get_visibility ( relationship_layout );
         if ( PENCIL_VISIBILITY_IMPLICIT == show_relation )
