@@ -16,7 +16,12 @@ static test_case_result_t test_set_envelope_box_too_small( test_fixture_t *fix )
 test_suite_t pencil_classifier_composer_test_get_suite(void)
 {
     test_suite_t result;
-    test_suite_init( &result, "pencil_classifier_composer_test_get_suite", &set_up, &tear_down );
+    test_suite_init( &result,
+                     "pencil_classifier_composer_test_get_suite",
+                     TEST_CATEGORY_UNIT | TEST_CATEGORY_CONTINUOUS | TEST_CATEGORY_COVERAGE,
+                     &set_up,
+                     &tear_down
+                   );
     test_suite_add_test_case( &result, "test_expand_space", &test_expand_space );
     test_suite_add_test_case( &result, "test_set_envelope_box", &test_set_envelope_box );
     test_suite_add_test_case( &result, "test_set_envelope_box_too_small", &test_set_envelope_box_too_small );
