@@ -11,6 +11,17 @@
 
 #include "u8stream/universal_output_stream.h"
 
+/*!
+ *  \brief constant that declares the size of the internal buffer
+ */
+enum universal_memory_output_stream_0term_enum {
+    UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_NONE = 0,  /*!< no 0 termination of output buffer */
+    UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_BYTE = 1,  /*!< simple 0 termination of output buffer */
+    UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_UTF8 = 2,  /*!< utf8-aware 0 termination of output buffer */
+};
+
+typedef enum universal_memory_output_stream_0term_enum universal_memory_output_stream_0term_t;
+
 /*!
  *  \brief attributes of the universal_memory_output_stream
  */
@@ -19,6 +30,7 @@ struct universal_memory_output_stream_struct {
     void* mem_buf_start;  /*!< output memory buffer start */
     size_t mem_buf_size;  /*!< output memory buffer size */
     size_t mem_buf_filled;  /*!< number of bytes written to the output memory buffer */
+    universal_memory_output_stream_0term_t mode;  /*!< mode defines if and how the memory buffer shall be 0-terminated */
 };
 
 typedef struct universal_memory_output_stream_struct universal_memory_output_stream_t;
@@ -29,21 +41,48 @@ typedef struct universal_memory_output_stream_struct universal_memory_output_str
  *  \param this_ pointer to own object attributes
  *  \param mem_buf_start address of memory buffer
  *  \param mem_buf_size size of the memory buffer
+ *  \param mode defines if and how the memory buffer shall be 0-terminated when flush is called
  */
 void universal_memory_output_stream_init( universal_memory_output_stream_t *this_,
                                           void* mem_buf_start,
-                                          size_t mem_buf_size
+                                          size_t mem_buf_size,
+                                          universal_memory_output_stream_0term_t mode
                                         );
 
 /*!
  *  \brief destroys the universal_memory_output_stream_t
  *
  *  \param this_ pointer to own object attributes
+ *  \return U8_ERROR_NONE in case of success, U8_ERROR_AT_FILE_WRITE if 0-term cannot be appended without overwriting data
  */
-void universal_memory_output_stream_destroy( universal_memory_output_stream_t *this_ );
+u8_error_t universal_memory_output_stream_destroy( universal_memory_output_stream_t *this_ );
 
 /*!
- *  \brief resets write position to 0 of this memory output stream,
+ *  \brief gets the start address of the memory buffer
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return start address of the memory buffer
+ */
+static inline void* universal_memory_output_stream_get_start ( const universal_memory_output_stream_t *this_ );
+
+/*!
+ *  \brief gets the size of the memory buffer
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return size of the memory buffer
+ */
+static inline size_t universal_memory_output_stream_get_size ( const universal_memory_output_stream_t *this_ );
+
+/*!
+ *  \brief gets the fill quantity of the memory buffer
+ *
+ *  \param this_ pointer to own object attributes
+ *  \return fill quantity of the memory buffer
+ */
+static inline size_t universal_memory_output_stream_get_fill ( const universal_memory_output_stream_t *this_ );
+
+/*!
+ *  \brief resets write position to 0 of this memory output stream
  *
  *  \param this_ pointer to own object attributes
  *  \return U8_ERROR_NONE in case of success, U8_ERROR_AT_FILE_WRITE otherwise
@@ -63,6 +102,10 @@ u8_error_t universal_memory_output_stream_write ( universal_memory_output_stream
 /*!
  *  \brief flushes buffers
  *
+ *  After flushing the buffer, in case UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_BYTE
+ *  or UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_UTF8, the buffer is 0-terminated by
+ *  universal_memory_output_stream_private_write_0term().
+ *
  *  \param this_ pointer to own object attributes
  *  \return U8_ERROR_NONE in case of success, U8_ERROR_AT_FILE_WRITE otherwise
  */
@@ -73,6 +116,8 @@ u8_error_t universal_memory_output_stream_flush( universal_memory_output_stream_
  *
  *  If the memory buffer is full, the last byte is overwritten by zero
  *  to ensure that even in this error case, the buffer is null-terminated.
+ *  In case of UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_UTF8 the terminating zero is written
+ *  after the last complete utf8 codepoint.
  *
  *  \param this_ pointer to own object attributes
  *  \param utf8_mode true ensures that no code point is cut in half
@@ -80,7 +125,7 @@ u8_error_t universal_memory_output_stream_flush( universal_memory_output_stream_
  *          U8_ERROR_CONFIG_OUT_OF_RANGE if memory buffer has size 0,
  *          U8_ERROR_AT_FILE_WRITE otherwise
  */
-u8_error_t universal_memory_output_stream_write_0term ( universal_memory_output_stream_t *this_, bool utf8_mode );
+static inline u8_error_t universal_memory_output_stream_private_write_0term ( universal_memory_output_stream_t *this_, bool utf8_mode );
 
 /*!
  *  \brief gets the output stream interface of this universal_memory_output_stream_t
@@ -90,6 +135,8 @@ u8_error_t universal_memory_output_stream_write_0term ( universal_memory_output_
  */
 universal_output_stream_t* universal_memory_output_stream_get_output_stream( universal_memory_output_stream_t *this_ );
 
+#include "universal_memory_output_stream.inl"
+
 #endif  /* UNIVERSAL_MEMORY_OUTPUT_STREAM_H */
 
 
