@@ -38,7 +38,7 @@ typedef struct utf8codepointiterator_struct utf8codepointiterator_t;
  *  \param this_ pointer to own object attributes
  *  \param stringview list of code points
  */
-static inline void utf8codepointiterator_init ( utf8codepointiterator_t *this_, utf8stringview_t stringview );
+static inline void utf8codepointiterator_init ( utf8codepointiterator_t *this_, const utf8stringview_t *stringview );
 
 /*!
  *  \brief destroys the utf8codepointiterator_t struct
@@ -85,7 +85,7 @@ static inline void utf8codepointiterator_private_step_to_next ( utf8codepointite
 
 
 /*
-Copyright 2021-2023 Andreas Warnke
+Copyright 2021-2024 Andreas Warnke
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
