@@ -82,7 +82,7 @@ u8_error_t universal_file_output_stream_write ( universal_file_output_stream_t *
             size_t out_count;
             out_count = fwrite( ((const char*)start)+written, 1, remaining, (*this_).output );
             assert( out_count != 0 );  /* this should not happen, but do not take this for granted */
-            out_count = U8_FAULT_INJECT_COND( U8_TEST_COND_FWRITE, 0, out_count );
+            U8_FAULT_INJECT_COND_SET( U8_TEST_COND_FWRITE, out_count, 0 );
             if ( out_count == 0 )
             {
                 U8_LOG_ERROR_INT( "not all bytes could be written. missing:", remaining );
@@ -113,7 +113,7 @@ u8_error_t universal_file_output_stream_flush( universal_file_output_stream_t *t
     {
         int flush_err = fflush( (*this_).output );
         assert( flush_err == 0 );  /* this should not happen, but do not take this for granted */
-        flush_err = U8_FAULT_INJECT_COND( U8_TEST_COND_FFLUSH, EOF, flush_err );
+        U8_FAULT_INJECT_COND_SET( U8_TEST_COND_FFLUSH, flush_err, EOF );
         if ( 0 != flush_err )
         {
             U8_LOG_ERROR_INT("error at flushing file:",flush_err);
@@ -139,7 +139,7 @@ u8_error_t universal_file_output_stream_close( universal_file_output_stream_t *t
     {
         int close_err = fclose( (*this_).output );
         assert( close_err == 0 );  /* this should not happen, but do not take this for granted */
-        close_err = U8_FAULT_INJECT_COND( U8_TEST_COND_FCLOSE, EOF, close_err );
+        U8_FAULT_INJECT_COND_SET( U8_TEST_COND_FCLOSE, close_err, EOF );
         if ( 0 != close_err )
         {
             U8_LOG_ERROR_INT("error at closing file:",close_err);
