@@ -2,7 +2,6 @@
 
 #include "u8stream/universal_memory_output_stream.h"
 #include "u8stream/universal_output_stream_if.h"
-#include "utf8stringbuf/utf8stringview.h"
 #include "u8/u8_trace.h"
 #include "u8/u8_log.h"
 #include <string.h>
@@ -17,7 +16,8 @@ static const universal_output_stream_if_t universal_memory_output_stream_private
 
 void universal_memory_output_stream_init ( universal_memory_output_stream_t *this_,
                                            void* mem_buf_start,
-                                           size_t mem_buf_size )
+                                           size_t mem_buf_size,
+                                           universal_memory_output_stream_0term_t mode )
 {
     U8_TRACE_BEGIN();
     assert( mem_buf_start != NULL );
@@ -25,21 +25,25 @@ void universal_memory_output_stream_init ( universal_memory_output_stream_t *thi
     (*this_).mem_buf_start = mem_buf_start;
     (*this_).mem_buf_size = mem_buf_size;
     (*this_).mem_buf_filled = 0;
+    (*this_).mode = mode;
     universal_output_stream_private_init( &((*this_).output_stream), &universal_memory_output_stream_private_if, this_ );
 
     U8_TRACE_END();
 }
 
-void universal_memory_output_stream_destroy( universal_memory_output_stream_t *this_ )
+u8_error_t universal_memory_output_stream_destroy( universal_memory_output_stream_t *this_ )
 {
     U8_TRACE_BEGIN();
 
+    const u8_error_t err = universal_memory_output_stream_flush( this_ );
+
     (*this_).mem_buf_start = NULL;
     (*this_).mem_buf_size = 0;
     (*this_).mem_buf_filled = 0;
     universal_output_stream_private_destroy( &((*this_).output_stream) );
 
-    U8_TRACE_END();
+    U8_TRACE_END_ERR(err);
+    return err;
 }
 
 u8_error_t universal_memory_output_stream_reset ( universal_memory_output_stream_t *this_ )
@@ -83,60 +87,32 @@ u8_error_t universal_memory_output_stream_write ( universal_memory_output_stream
 }
 
 u8_error_t universal_memory_output_stream_flush( universal_memory_output_stream_t *this_ )
-{
-    U8_TRACE_BEGIN();
-    assert( (*this_).mem_buf_start != NULL );
-    const u8_error_t err = U8_ERROR_NONE;
-
-    U8_TRACE_END_ERR(err);
-    return err;
-}
-
-u8_error_t universal_memory_output_stream_write_0term ( universal_memory_output_stream_t *this_, bool utf8_mode )
 {
     U8_TRACE_BEGIN();
     assert( (*this_).mem_buf_start != NULL );
     u8_error_t err = U8_ERROR_NONE;
 
-    if ( (*this_).mem_buf_size == 0 )
+    switch( (*this_).mode )
     {
-        U8_LOG_ERROR( "buffer size is 0; buffer is not terminated by zero." );
-        err = U8_ERROR_CONFIG_OUT_OF_RANGE;
-    }
-    else if ( (*this_).mem_buf_filled < (*this_).mem_buf_size )
-    {
-        /* add a terminating zero */
-        char *const term_char = &(  (*(  (char(*)[])(*this_).mem_buf_start  ))[(*this_).mem_buf_filled]  );
-        *term_char = '\0';
-        (*this_).mem_buf_filled += sizeof(char);
-    }
-    else
-    {
-        if ( utf8_mode )
+        case UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_BYTE:
         {
-            utf8stringview_t view_on_buf;
-            const utf8error_t cut = utf8stringview_init( &view_on_buf, (*this_).mem_buf_start, (*this_).mem_buf_size-1 );
-            char *const last_char = &(  (*(  (char(*)[])utf8stringview_get_start(&view_on_buf)  ))[utf8stringview_get_length(&view_on_buf)]  );
-            *last_char = '\0';
-            utf8stringview_destroy( &view_on_buf );
-            if ( cut == UTF8ERROR_SUCCESS )
-            {
-                U8_TRACE_INFO( "last byte overwritten by terminating zero" );
-            }
-            else
-            {
-                U8_TRACE_INFO( "multiple last bytes dropped by terminating zero" );
-            }
+            err = universal_memory_output_stream_private_write_0term( this_, false );
         }
-        else
-        {
-            char *const last_char = &(  (*(  (char(*)[])(*this_).mem_buf_start  ))[(*this_).mem_buf_size - 1]  );
-            *last_char = '\0';
-            U8_TRACE_INFO( "last byte overwritten by terminating zero" );
-        }
-        err = U8_ERROR_AT_FILE_WRITE;
-    }
+        break;
 
+        case UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_UTF8:
+        {
+            err = universal_memory_output_stream_private_write_0term( this_, true );
+        }
+        break;
+
+        default:
+        case UNIVERSAL_MEMORY_OUTPUT_STREAM_0TERM_NONE:
+        {
+            /* no 0term to be appended */
+        }
+        break;
+    }
 
     U8_TRACE_END_ERR(err);
     return err;
