@@ -1,7 +1,6 @@
 /* File: utf8codepoint_test.c; Copyright and License: see below */
 
 #include "utf8codepoint_test.h"
-#include "utf8stringbuf/utf8stringbuf.h"
 #include "utf8stringbuf/utf8codepoint.h"
 #include "test_fixture.h"
 #include "test_expect.h"
@@ -14,7 +13,6 @@ static test_fixture_t * set_up();
 static void tear_down( test_fixture_t *fix );
 static test_case_result_t testInit1( test_fixture_t *fix );
 static test_case_result_t testInit2( test_fixture_t *fix );
-static test_case_result_t testIntToUtf8ToInt( test_fixture_t *fix );
 static test_case_result_t testIntToUtf8( test_fixture_t *fix );
 static test_case_result_t testUnicode( test_fixture_t *fix );
 
@@ -29,7 +27,6 @@ test_suite_t utf8codepoint_test_get_suite(void)
                    );
     test_suite_add_test_case( &result, "testInit1", &testInit1 );
     test_suite_add_test_case( &result, "testInit2", &testInit2 );
-    test_suite_add_test_case( &result, "testIntToUtf8ToInt", &testIntToUtf8ToInt );
     test_suite_add_test_case( &result, "testIntToUtf8", &testIntToUtf8 );
     test_suite_add_test_case( &result, "testUnicode", &testUnicode );
     return result;
@@ -154,89 +151,11 @@ static test_case_result_t testInit2( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 0x0, utf8codepoint_get_char( code_point2 ) );
     TEST_EXPECT_EQUAL_INT( 0, utf8codepoint_is_valid( code_point2 ) );
 
-    return TEST_CASE_RESULT_OK;
-}
+    code_point2 = utf8codepoint_init( "\xF7\xBF\xBF\xBF", 5 );
+    TEST_EXPECT_EQUAL_INT( UTF8CODEPOINT_INVALID_LEN, utf8codepoint_get_length( code_point2 ) );
+    TEST_EXPECT_EQUAL_INT( 0x1fffff, utf8codepoint_get_char( code_point2 ) );
+    TEST_EXPECT_EQUAL_INT( 0, utf8codepoint_is_valid( code_point2 ) );
 
-static test_case_result_t testIntToUtf8ToInt( test_fixture_t *fix )
-{
-    utf8codepoint_t result;
-    char dynTestArr1[7] = "";
-    utf8stringbuf_t dynTestBuf1 = UTF8STRINGBUF(dynTestArr1);
-
-    /* check to convert a character to and back from utf8 */
-    /* 0 */
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x0, utf8codepoint_get_char(result) );
-
-    /* 1 byte code points */
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x01 );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x01, utf8codepoint_get_char(result) );
-
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x7f );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x7f, utf8codepoint_get_char(result) );
-
-    /* 2 byte code points */
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x80 );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 2, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x80, utf8codepoint_get_char(result) );
-
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x07ff );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 2, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x07ff, utf8codepoint_get_char(result) );
-
-    /* 3 byte code points */
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x800 );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 3, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x800, utf8codepoint_get_char(result) );
-
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0xffff );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 3, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0xffff, utf8codepoint_get_char(result) );
-
-    /* 4 byte code points */
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x10000 );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 4, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x10000, utf8codepoint_get_char(result) );
-
-    utf8stringbuf_clear( dynTestBuf1 );
-    utf8stringbuf_append_char( dynTestBuf1, 0x10ffff );
-    result = utf8stringbuf_get_char_at( dynTestBuf1, 0 );
-    TEST_EXPECT_EQUAL_INT( 1, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 4, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x10ffff, utf8codepoint_get_char(result) );
-
-    char invalid_1fffff[5] = "\xF7\xBF\xBF\xBF";
-    utf8stringbuf_t invalidBuf = UTF8STRINGBUF(invalid_1fffff);
-
-    result = utf8stringbuf_get_char_at( invalidBuf, 0 );
-    TEST_EXPECT_EQUAL_INT( 0, utf8codepoint_is_valid(result) );
-    TEST_EXPECT_EQUAL_INT( 0, utf8codepoint_get_length(result) );
-    TEST_EXPECT_EQUAL_INT( 0x1fffff, utf8codepoint_get_char(result) );
     return TEST_CASE_RESULT_OK;
 }
 
