@@ -15,16 +15,22 @@ static void tear_down( test_fixture_t *fix );
 static test_case_result_t testInit( test_fixture_t *fix );
 static test_case_result_t testClear( test_fixture_t *fix );
 static test_case_result_t testLength( test_fixture_t *fix );
+static test_case_result_t testGetView( test_fixture_t *fix );
 static test_case_result_t testEquals( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testEqualsRegion( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_UNCHECKED_RANGE */
 static test_case_result_t testStartsWith( test_fixture_t *fix );
 static test_case_result_t testEndsWith( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testFindFirst( test_fixture_t *fix );
 static test_case_result_t testFindNext( test_fixture_t *fix );
 static test_case_result_t testFindLast( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 static test_case_result_t testCopyBuf( test_fixture_t *fix );
 static test_case_result_t testCopyStr( test_fixture_t *fix );
 static test_case_result_t testCopyWithCutUtf8( test_fixture_t *fix );
+static test_case_result_t testCopyView( test_fixture_t *fix );
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testCopyRegion( test_fixture_t *fix );
 static test_case_result_t testReplaceRegion( test_fixture_t *fix );
@@ -35,7 +41,9 @@ static test_case_result_t testReplaceRegionBuf( test_fixture_t *fix );
 static test_case_result_t testReplaceAll( test_fixture_t *fix );
 static test_case_result_t testReplaceAllBadCases( test_fixture_t *fix );
 static test_case_result_t testReplaceAllStr( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_DEPRECATED_INPLACE
 static test_case_result_t testReplaceAllBuf( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INPLACE */
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testInsertBuf( test_fixture_t *fix );
 static test_case_result_t testInsertStr( test_fixture_t *fix );
@@ -50,8 +58,10 @@ static test_case_result_t testAppendHex( test_fixture_t *fix );
 static test_case_result_t testAppendChar( test_fixture_t *fix );
 static test_case_result_t testAppendWStr( test_fixture_t *fix );
 static test_case_result_t testAppendView( test_fixture_t *fix );
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testCharAt( test_fixture_t *fix );
 static test_case_result_t testCharAtLoops( test_fixture_t *fix );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 static test_case_result_t testGetEnd( test_fixture_t *fix );
 
 test_suite_t utf8stringbuf_test_get_suite(void)
@@ -66,16 +76,22 @@ test_suite_t utf8stringbuf_test_get_suite(void)
     test_suite_add_test_case( &result, "testInit", &testInit );
     test_suite_add_test_case( &result, "testClear", &testClear );
     test_suite_add_test_case( &result, "testLength", &testLength );
+    test_suite_add_test_case( &result, "testGetView", &testGetView );
     test_suite_add_test_case( &result, "testEquals", &testEquals );
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
     test_suite_add_test_case( &result, "testEqualsRegion", &testEqualsRegion );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
     test_suite_add_test_case( &result, "testStartsWith", &testStartsWith );
     test_suite_add_test_case( &result, "testEndsWith", &testEndsWith );
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
     test_suite_add_test_case( &result, "testFindFirst", &testFindFirst );
     test_suite_add_test_case( &result, "testFindNext", &testFindNext );
     test_suite_add_test_case( &result, "testFindLast", &testFindLast );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
     test_suite_add_test_case( &result, "testCopyBuf", &testCopyBuf );
     test_suite_add_test_case( &result, "testCopyStr", &testCopyStr );
     test_suite_add_test_case( &result, "testCopyWithCutUtf8", &testCopyWithCutUtf8 );
+    test_suite_add_test_case( &result, "testCopyView", &testCopyView );
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
     test_suite_add_test_case( &result, "testCopyRegion", &testCopyRegion );
     test_suite_add_test_case( &result, "testReplaceRegion", &testReplaceRegion );
@@ -86,7 +102,9 @@ test_suite_t utf8stringbuf_test_get_suite(void)
     test_suite_add_test_case( &result, "testReplaceAll", &testReplaceAll );
     test_suite_add_test_case( &result, "testReplaceAllBadCases", &testReplaceAllBadCases );
     test_suite_add_test_case( &result, "testReplaceAllStr", &testReplaceAllStr );
+#ifdef UTF8STRINGBUF_DEPRECATED_INPLACE
     test_suite_add_test_case( &result, "testReplaceAllBuf", &testReplaceAllBuf );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INPLACE */
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
     test_suite_add_test_case( &result, "testInsertBuf", &testInsertBuf );
     test_suite_add_test_case( &result, "testInsertStr", &testInsertStr );
@@ -101,8 +119,10 @@ test_suite_t utf8stringbuf_test_get_suite(void)
     test_suite_add_test_case( &result, "testAppendChar", &testAppendChar );
     test_suite_add_test_case( &result, "testAppendWStr", &testAppendWStr );
     test_suite_add_test_case( &result, "testAppendView", &testAppendView );
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
     test_suite_add_test_case( &result, "testCharAt", &testCharAt );
     test_suite_add_test_case( &result, "testCharAtLoops", &testCharAtLoops );
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
     test_suite_add_test_case( &result, "testGetEnd", &testGetEnd );
     return result;
 }
@@ -278,6 +298,11 @@ static test_case_result_t testInit( test_fixture_t *fix )
     utf8stringbuf_t dynTestBuf3 = utf8stringbuf_init( 10, dynTestArr2 );
     TEST_EXPECT( utf8stringbuf_get_string( dynTestBuf3 ) == dynTestArr2 );
     TEST_EXPECT_EQUAL_INT( 10, utf8stringbuf_get_size( dynTestBuf3 ) );
+
+    /* check NULL initialization */
+    utf8stringbuf_t nullTestBuf = utf8stringbuf_init( 4, NULL );
+    TEST_EXPECT_EQUAL_INT( 1, utf8stringbuf_get_size( nullTestBuf ) );
+
     return TEST_CASE_RESULT_OK;
 }
 
@@ -298,6 +323,30 @@ static test_case_result_t testClear( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+static test_case_result_t testLength( test_fixture_t *fix )
+{
+    int len;
+
+    /* check utf8stringbuf_get_length */
+    len = utf8stringbuf_get_length( (*fix).one_byte_buf );
+    TEST_EXPECT_EQUAL_INT( 0, len );
+    len = utf8stringbuf_get_length( (*fix).four_byte_buf );
+    TEST_EXPECT_EQUAL_INT( 2, len );
+    len = utf8stringbuf_get_length( (*fix).mega_byte_buf );
+    TEST_EXPECT_EQUAL_INT( UTF8STRINGBUFTEST_MEGASIZE-1, len );
+    return TEST_CASE_RESULT_OK;
+}
+
+static test_case_result_t testGetView( test_fixture_t *fix )
+{
+    char dynTestArr[] = "Hello";
+    utf8stringbuf_t dynTestBuf = UTF8STRINGBUF( dynTestArr );
+    const utf8stringview_t testme = utf8stringbuf_get_view( dynTestBuf );
+    TEST_EXPECT_EQUAL_PTR( &dynTestArr, utf8stringview_get_start( &testme ) );
+    TEST_EXPECT_EQUAL_INT( 5, utf8stringview_get_length( &testme ) );
+    return TEST_CASE_RESULT_OK;
+}
+
 static test_case_result_t testEquals( test_fixture_t *fix )
 {
     //  prepare
@@ -333,6 +382,7 @@ static test_case_result_t testEquals( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testEqualsRegion( test_fixture_t *fix )
 {
     //  prepare
@@ -385,20 +435,7 @@ static test_case_result_t testEqualsRegion( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 0, equal );
     return TEST_CASE_RESULT_OK;
 }
-
-static test_case_result_t testLength( test_fixture_t *fix )
-{
-    int len;
-
-    /* check utf8stringbuf_get_length */
-    len = utf8stringbuf_get_length( (*fix).one_byte_buf );
-    TEST_EXPECT_EQUAL_INT( 0, len );
-    len = utf8stringbuf_get_length( (*fix).four_byte_buf );
-    TEST_EXPECT_EQUAL_INT( 2, len );
-    len = utf8stringbuf_get_length( (*fix).mega_byte_buf );
-    TEST_EXPECT_EQUAL_INT( UTF8STRINGBUFTEST_MEGASIZE-1, len );
-    return TEST_CASE_RESULT_OK;
-}
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
 static test_case_result_t testStartsWith( test_fixture_t *fix )
 {
@@ -624,6 +661,27 @@ static test_case_result_t testCopyWithCutUtf8( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+static test_case_result_t testCopyView( test_fixture_t *fix )
+{
+    utf8error_t error;
+    int equal;
+
+    /* check success */
+    error = utf8stringbuf_copy_view( (*fix).four_byte_buf, &UTF8STRINGVIEW_STR("Hi") );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( (*fix).four_byte_buf, "Hi" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* check truncated */
+    error = utf8stringbuf_copy_view( (*fix).four_byte_buf, &UTF8STRINGVIEW_STR("H\xE2\x80\x8B") );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_TRUNCATED, error );
+    equal = utf8stringbuf_equals_str( (*fix).four_byte_buf, "H" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    return TEST_CASE_RESULT_OK;
+}
+
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testFindFirst( test_fixture_t *fix )
 {
     int pos;
@@ -675,7 +733,9 @@ static test_case_result_t testFindFirst( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 0, pos );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testFindNext( test_fixture_t *fix )
 {
     int pos;
@@ -728,7 +788,9 @@ static test_case_result_t testFindNext( test_fixture_t *fix )
 
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testFindLast( test_fixture_t *fix )
 {
     int pos;
@@ -767,6 +829,7 @@ static test_case_result_t testFindLast( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 4, pos );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testCopyRegion( test_fixture_t *fix )
@@ -1267,6 +1330,7 @@ static test_case_result_t testReplaceAllStr( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INPLACE
 static test_case_result_t testReplaceAllBuf( test_fixture_t *fix )
 {
     /* utf8stringbuf_replace_all_buf_by_buf is just a wrapper around utf8stringbuf_replace_all */
@@ -1283,6 +1347,7 @@ static test_case_result_t testReplaceAllBuf( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 1, equal );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INPLACE */
 
 #ifdef UTF8STRINGBUF_UNCHECKED_RANGE
 static test_case_result_t testInsertBuf( test_fixture_t *fix )
@@ -1572,12 +1637,76 @@ static test_case_result_t testAppendChar( test_fixture_t *fix )
     equal = utf8stringbuf_equals_str( dynTestBuf1, "Hel" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
 
+    /* append zero */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x0 );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x1 1-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x01 );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\x01" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x7f 1-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x7f );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\x7f" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x80 2-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x80 );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xC2\x80" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x7ff 2-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x07ff );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xDF\xBF" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x800 3-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x800 );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xE0\xA0\x80" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0xffff 3-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0xffff );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xEF\xBF\xBF" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x10000 4-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x10000 );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xF0\x90\x80\x80" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
+    /* append 0x10ffff 4-byte code point */
+    utf8stringbuf_clear( dynTestBuf1 );
+    error = utf8stringbuf_append_char( dynTestBuf1, 0x10ffff );
+    TEST_EXPECT_EQUAL_INT( UTF8ERROR_SUCCESS, error );
+    equal = utf8stringbuf_equals_str( dynTestBuf1, "\xF4\x8F\xBF\xBF" );
+    TEST_EXPECT_EQUAL_INT( 1, equal );
+
     /* append illegal code point */
     utf8stringbuf_clear( dynTestBuf1 );
     error = utf8stringbuf_append_char( dynTestBuf1, 0x80000000 );
     TEST_EXPECT_EQUAL_INT( UTF8ERROR_NOT_A_CODEPOINT, error );
     equal = utf8stringbuf_equals_str( dynTestBuf1, "" );
     TEST_EXPECT_EQUAL_INT( 1, equal );
+
     return TEST_CASE_RESULT_OK;
 }
 
@@ -1675,6 +1804,7 @@ static test_case_result_t testAppendView( test_fixture_t *fix )
     return TEST_CASE_RESULT_OK;
 }
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testCharAt( test_fixture_t *fix )
 {
     utf8codepoint_t result;
@@ -1715,7 +1845,9 @@ static test_case_result_t testCharAt( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 0x0, utf8codepoint_get_char(result) );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
+#ifdef UTF8STRINGBUF_DEPRECATED_INDEX
 static test_case_result_t testCharAtLoops( test_fixture_t *fix )
 {
     utf8codepoint_t result;
@@ -1781,6 +1913,7 @@ static test_case_result_t testCharAtLoops( test_fixture_t *fix )
     TEST_EXPECT_EQUAL_INT( 3, countCodePoints );
     return TEST_CASE_RESULT_OK;
 }
+#endif  /* UTF8STRINGBUF_DEPRECATED_INDEX */
 
 static test_case_result_t testGetEnd( test_fixture_t *fix )
 {
